ActionTarget class

An ActionTarget object.

Constructors

ActionTarget({required String actionTargetArn, required String description, required String name})
ActionTarget.fromJson(Map<String, dynamic> json)
factory

Properties

actionTargetArn → String
The ARN for the target action.
final
description → String
The description of the target action.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the action target.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited