AvailabilityZone class

Information about an Availability Zone.

Constructors

AvailabilityZone({String? subnetId, String? zoneName})
AvailabilityZone.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetId → String?
The ID of the subnet. You can specify one subnet per Availability Zone.
final
zoneName → String?
The name of the Availability Zone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited