AwsApiGatewayAccessLogSettings class

Contains information about settings for logging access for the stage.

Constructors

AwsApiGatewayAccessLogSettings({String? destinationArn, String? format})
AwsApiGatewayAccessLogSettings.fromJson(Map<String, dynamic> json)
factory

Properties

destinationArn → String?
The ARN of the CloudWatch Logs log group that receives the access logs.
final
format → String?
A single-line format of the access logs of data, as specified by selected $context variables. The format must include at least $context.requestId.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited