AwsApiGatewayCanarySettings class

Contains information about settings for canary deployment in the stage.

Constructors

AwsApiGatewayCanarySettings({String? deploymentId, double? percentTraffic, Map<String, String>? stageVariableOverrides, bool? useStageCache})
AwsApiGatewayCanarySettings.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentId → String?
The deployment identifier for the canary deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
percentTraffic → double?
The percentage of traffic that is diverted to a canary deployment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageVariableOverrides → Map<String, String>?
Stage variables that are overridden in the canary release deployment. The variables include new stage variables that are introduced in the canary.
final
useStageCache → bool?
Indicates whether the canary deployment uses the stage cache.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited