AwsApiGatewayMethodSettings class

Defines settings for a method for the stage.

Constructors

AwsApiGatewayMethodSettings({bool? cacheDataEncrypted, int? cacheTtlInSeconds, bool? cachingEnabled, bool? dataTraceEnabled, String? httpMethod, String? loggingLevel, bool? metricsEnabled, bool? requireAuthorizationForCacheControl, String? resourcePath, int? throttlingBurstLimit, double? throttlingRateLimit, String? unauthorizedCacheControlHeaderStrategy})
AwsApiGatewayMethodSettings.fromJson(Map<String, dynamic> json)
factory

Properties

cacheDataEncrypted → bool?
Indicates whether the cached responses are encrypted.
final
cacheTtlInSeconds → int?
Specifies the time to live (TTL), in seconds, for cached responses. The higher the TTL, the longer the response is cached.
final
cachingEnabled → bool?
Indicates whether responses are cached and returned for requests. For responses to be cached, a cache cluster must be enabled on the stage.
final
dataTraceEnabled → bool?
Indicates whether data trace logging is enabled for the method. Data trace logging affects the log entries that are pushed to CloudWatch Logs.
final
hashCode → int
The hash code for this object.
no setterinherited
httpMethod → String?
The HTTP method. You can use an asterisk (*) as a wildcard to apply method settings to multiple methods.
final
loggingLevel → String?
The logging level for this method. The logging level affects the log entries that are pushed to CloudWatch Logs.
final
metricsEnabled → bool?
Indicates whether CloudWatch metrics are enabled for the method.
final
requireAuthorizationForCacheControl → bool?
Indicates whether authorization is required for a cache invalidation request.
final
resourcePath → String?
The resource path for this method. Forward slashes (/) are encoded as ~1 . The initial slash must include a forward slash.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throttlingBurstLimit → int?
The throttling burst limit for the method.
final
throttlingRateLimit → double?
The throttling rate limit for the method.
final
unauthorizedCacheControlHeaderStrategy → String?
Indicates how to handle unauthorized requests for cache invalidation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited