AwsApiGatewayRestApiDetails class

contains information about a REST API in version 1 of Amazon API Gateway.

Constructors

AwsApiGatewayRestApiDetails({String? apiKeySource, List<String>? binaryMediaTypes, String? createdDate, String? description, AwsApiGatewayEndpointConfiguration? endpointConfiguration, String? id, int? minimumCompressionSize, String? name, String? version})
AwsApiGatewayRestApiDetails.fromJson(Map<String, dynamic> json)
factory

Properties

apiKeySource → String?
The source of the API key for metering requests according to a usage plan.
final
binaryMediaTypes → List<String>?
The list of binary media types supported by the REST API.
final
createdDate → String?
Indicates when the API was created.
final
description → String?
A description of the REST API.
final
endpointConfiguration → AwsApiGatewayEndpointConfiguration?
The endpoint configuration of the REST API.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the REST API.
final
minimumCompressionSize → int?
The minimum size in bytes of a payload before compression is enabled.
final
name → String?
The name of the REST API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
The version identifier for the REST API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited