AwsApiGatewayV2RouteSettings class

Contains route settings for a stage.

Constructors

AwsApiGatewayV2RouteSettings({bool? dataTraceEnabled, bool? detailedMetricsEnabled, String? loggingLevel, int? throttlingBurstLimit, double? throttlingRateLimit})
AwsApiGatewayV2RouteSettings.fromJson(Map<String, dynamic> json)
factory

Properties

dataTraceEnabled → bool?
Indicates whether data trace logging is enabled. Data trace logging affects the log entries that are pushed to CloudWatch Logs. Supported only for WebSocket APIs.
final
detailedMetricsEnabled → bool?
Indicates whether detailed metrics are enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
loggingLevel → String?
The logging level. The logging level affects the log entries that are pushed to CloudWatch Logs. Supported only for WebSocket APIs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throttlingBurstLimit → int?
The throttling burst limit.
final
throttlingRateLimit → double?
The throttling rate limit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited