AwsAutoScalingAutoScalingGroupDetails class

Provides details about an auto scaling group.

Constructors

AwsAutoScalingAutoScalingGroupDetails({String? createdTime, int? healthCheckGracePeriod, String? healthCheckType, String? launchConfigurationName, List<String>? loadBalancerNames})
AwsAutoScalingAutoScalingGroupDetails.fromJson(Map<String, dynamic> json)
factory

Properties

createdTime → String?
Indicates when the auto scaling group was created.
final
hashCode → int
The hash code for this object.
no setterinherited
healthCheckGracePeriod → int?
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
final
healthCheckType → String?
The service to use for the health checks.
final
launchConfigurationName → String?
The name of the launch configuration.
final
loadBalancerNames → List<String>?
The list of load balancers associated with the group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited