AwsCertificateManagerCertificateDetails class

Provides details about an AWS Certificate Manager certificate.

Constructors

AwsCertificateManagerCertificateDetails({String? certificateAuthorityArn, String? createdAt, String? domainName, List<AwsCertificateManagerCertificateDomainValidationOption>? domainValidationOptions, List<AwsCertificateManagerCertificateExtendedKeyUsage>? extendedKeyUsages, String? failureReason, String? importedAt, List<String>? inUseBy, String? issuedAt, String? issuer, String? keyAlgorithm, List<AwsCertificateManagerCertificateKeyUsage>? keyUsages, String? notAfter, String? notBefore, AwsCertificateManagerCertificateOptions? options, String? renewalEligibility, AwsCertificateManagerCertificateRenewalSummary? renewalSummary, String? serial, String? signatureAlgorithm, String? status, String? subject, List<String>? subjectAlternativeNames, String? type})
AwsCertificateManagerCertificateDetails.fromJson(Map<String, dynamic> json)
factory

Properties

certificateAuthorityArn → String?
The ARN of the private certificate authority (CA) that will be used to issue the certificate.
final
createdAt → String?
Indicates when the certificate was requested.
final
domainName → String?
The fully qualified domain name (FQDN), such as www.example.com, that is secured by the certificate.
final
domainValidationOptions → List<AwsCertificateManagerCertificateDomainValidationOption>?
Contains information about the initial validation of each domain name that occurs as a result of the RequestCertificate request.
final
extendedKeyUsages → List<AwsCertificateManagerCertificateExtendedKeyUsage>?
Contains a list of Extended Key Usage X.509 v3 extension objects. Each object specifies a purpose for which the certificate public key can be used and consists of a name and an object identifier (OID).
final
failureReason → String?
For a failed certificate request, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
importedAt → String?
Indicates when the certificate was imported. Provided if the certificate type is IMPORTED.
final
inUseBy → List<String>?
The list of ARNs for the AWS resources that use the certificate.
final
issuedAt → String?
Indicates when the certificate was issued. Provided if the certificate type is AMAZON_ISSUED.
final
issuer → String?
The name of the certificate authority that issued and signed the certificate.
final
keyAlgorithm → String?
The algorithm that was used to generate the public-private key pair.
final
keyUsages → List<AwsCertificateManagerCertificateKeyUsage>?
A list of key usage X.509 v3 extension objects.
final
notAfter → String?
The time after which the certificate becomes invalid.
final
notBefore → String?
The time before which the certificate is not valid.
final
options → AwsCertificateManagerCertificateOptions?
Provides a value that specifies whether to add the certificate to a transparency log.
final
renewalEligibility → String?
Whether the certificate is eligible for renewal.
final
renewalSummary → AwsCertificateManagerCertificateRenewalSummary?
Information about the status of the AWS Certificate Manager managed renewal for the certificate. Provided only when the certificate type is AMAZON_ISSUED.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serial → String?
The serial number of the certificate.
final
signatureAlgorithm → String?
The algorithm that was used to sign the certificate.
final
status → String?
The status of the certificate.
final
subject → String?
The name of the entity that is associated with the public key contained in the certificate.
final
subjectAlternativeNames → List<String>?
One or more domain names (subject alternative names) included in the certificate. This list contains the domain names that are bound to the public key that is contained in the certificate.
final
type → String?
The source of the certificate. For certificates that AWS Certificate Manager provides, Type is AMAZON_ISSUED. For certificates that are imported with ImportCertificate, Type is IMPORTED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited