keyAlgorithm property
The algorithm that was used to generate the public-private key pair.
Valid values: RSA_2048 | RSA_1024 |
RSA_4096 | EC_prime256v1 | EC_secp384r1 |
EC_secp521r1
Implementation
final String? keyAlgorithm;
The algorithm that was used to generate the public-private key pair.
Valid values: RSA_2048 | RSA_1024 |
RSA_4096 | EC_prime256v1 | EC_secp384r1 |
EC_secp521r1
final String? keyAlgorithm;