AwsCertificateManagerCertificateDomainValidationOption class

Contains information about one of the following:

  • The initial validation of each domain name that occurs as a result of the RequestCertificate request
  • The validation of each domain name in the certificate, as it pertains to AWS Certificate Manager managed renewal

Constructors

AwsCertificateManagerCertificateDomainValidationOption({String? domainName, AwsCertificateManagerCertificateResourceRecord? resourceRecord, String? validationDomain, List<String>? validationEmails, String? validationMethod, String? validationStatus})
AwsCertificateManagerCertificateDomainValidationOption.fromJson(Map<String, dynamic> json)
factory

Properties

domainName → String?
A fully qualified domain name (FQDN) in the certificate.
final
hashCode → int
The hash code for this object.
no setterinherited
resourceRecord → AwsCertificateManagerCertificateResourceRecord?
The CNAME record that is added to the DNS database for domain validation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationDomain → String?
The domain name that AWS Certificate Manager uses to send domain validation emails.
final
validationEmails → List<String>?
A list of email addresses that AWS Certificate Manager uses to send domain validation emails.
final
validationMethod → String?
The method used to validate the domain name.
final
validationStatus → String?
The validation status of the domain name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited