AwsCertificateManagerCertificateResourceRecord class

Provides details about the CNAME record that is added to the DNS database for domain validation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of resource.
final
value → String?
The value of the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited