AwsCloudFrontDistributionCacheBehavior class

Information about a cache behavior for the distribution.

Constructors

AwsCloudFrontDistributionCacheBehavior({String? viewerProtocolPolicy})
AwsCloudFrontDistributionCacheBehavior.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewerProtocolPolicy → String?
The protocol that viewers can use to access the files in an origin. You can specify the following options:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited