AwsCloudFrontDistributionDetails class

A distribution configuration.

Constructors

AwsCloudFrontDistributionDetails({AwsCloudFrontDistributionCacheBehaviors? cacheBehaviors, AwsCloudFrontDistributionDefaultCacheBehavior? defaultCacheBehavior, String? defaultRootObject, String? domainName, String? eTag, String? lastModifiedTime, AwsCloudFrontDistributionLogging? logging, AwsCloudFrontDistributionOriginGroups? originGroups, AwsCloudFrontDistributionOrigins? origins, String? status, String? webAclId})
AwsCloudFrontDistributionDetails.fromJson(Map<String, dynamic> json)
factory

Properties

cacheBehaviors → AwsCloudFrontDistributionCacheBehaviors?
Provides information about the cache configuration for the distribution.
final
defaultCacheBehavior → AwsCloudFrontDistributionDefaultCacheBehavior?
The default cache behavior for the configuration.
final
defaultRootObject → String?
The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).
final
domainName → String?
The domain name corresponding to the distribution.
final
eTag → String?
The entity tag is a hash of the object.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → String?
Indicates when that the distribution was last modified.
final
logging → AwsCloudFrontDistributionLogging?
A complex type that controls whether access logs are written for the distribution.
final
originGroups → AwsCloudFrontDistributionOriginGroups?
Provides information about the origin groups in the distribution.
final
origins → AwsCloudFrontDistributionOrigins?
A complex type that contains information about origins for this distribution.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Indicates the current status of the distribution.
final
webAclId → String?
A unique identifier that specifies the AWS WAF web ACL, if any, to associate with this distribution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited