AwsCloudFrontDistributionLogging class

A complex type that controls whether access logs are written for the distribution.

Constructors

AwsCloudFrontDistributionLogging({String? bucket, bool? enabled, bool? includeCookies, String? prefix})
AwsCloudFrontDistributionLogging.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String?
The Amazon S3 bucket to store the access logs in.
final
enabled → bool?
With this field, you can enable or disable the selected distribution.
final
hashCode → int
The hash code for this object.
no setterinherited
includeCookies → bool?
Specifies whether you want CloudFront to include cookies in access logs.
final
prefix → String?
An optional string that you want CloudFront to use as a prefix to the access log filenames for this distribution.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited