AwsCloudFrontDistributionOriginGroupFailoverStatusCodes class

The status codes that cause an origin group to fail over.

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<int>?
The list of status code values that can cause a failover to the next origin.
final
quantity → int?
The number of status codes that can cause a failover.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited