AwsCloudFrontDistributionOriginItem class

A complex type that describes the Amazon S3 bucket, HTTP server (for example, a web server), Amazon Elemental MediaStore, or other server from which CloudFront gets your files.

Properties

domainName → String?
Amazon S3 origins: The DNS name of the Amazon S3 bucket from which you want CloudFront to get objects for this origin.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
A unique identifier for the origin or origin group.
final
originPath → String?
An optional element that causes CloudFront to request your content from a directory in your Amazon S3 bucket or your custom origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OriginConfig → AwsCloudFrontDistributionOriginS3OriginConfig?
An origin that is an S3 bucket that is not configured with static website hosting.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited