AwsCloudFrontDistributionOriginS3OriginConfig class

Information about an origin that is an S3 bucket that is not configured with static website hosting.

Properties

hashCode → int
The hash code for this object.
no setterinherited
originAccessIdentity → String?
The CloudFront origin access identity to associate with the origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited