AwsCloudTrailTrailDetails class

Provides details about a CloudTrail trail.

Constructors

AwsCloudTrailTrailDetails({String? cloudWatchLogsLogGroupArn, String? cloudWatchLogsRoleArn, bool? hasCustomEventSelectors, String? homeRegion, bool? includeGlobalServiceEvents, bool? isMultiRegionTrail, bool? isOrganizationTrail, String? kmsKeyId, bool? logFileValidationEnabled, String? name, String? s3BucketName, String? s3KeyPrefix, String? snsTopicArn, String? snsTopicName, String? trailArn})
AwsCloudTrailTrailDetails.fromJson(Map<String, dynamic> json)
factory

Properties

cloudWatchLogsLogGroupArn → String?
The ARN of the log group that CloudTrail logs are delivered to.
final
cloudWatchLogsRoleArn → String?
The ARN of the role that the CloudWatch Logs endpoint assumes when it writes to the log group.
final
hasCustomEventSelectors → bool?
Indicates whether the trail has custom event selectors.
final
hashCode → int
The hash code for this object.
no setterinherited
homeRegion → String?
The Region where the trail was created.
final
includeGlobalServiceEvents → bool?
Indicates whether the trail publishes events from global services such as IAM to the log files.
final
isMultiRegionTrail → bool?
Indicates whether the trail applies only to the current Region or to all Regions.
final
isOrganizationTrail → bool?
Whether the trail is created for all accounts in an organization in AWS Organizations, or only for the current AWS account.
final
kmsKeyId → String?
The AWS KMS key ID to use to encrypt the logs.
final
logFileValidationEnabled → bool?
Indicates whether CloudTrail log file validation is enabled.
final
name → String?
The name of the trail.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
The name of the S3 bucket where the log files are published.
final
s3KeyPrefix → String?
The S3 key prefix. The key prefix is added after the name of the S3 bucket where the log files are published.
final
snsTopicArn → String?
The ARN of the SNS topic that is used for notifications of log file delivery.
final
snsTopicName → String?
The name of the SNS topic that is used for notifications of log file delivery.
final
trailArn → String?
The ARN of the trail.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited