AwsCodeBuildProjectDetails class

Information about an AWS CodeBuild project.

Constructors

AwsCodeBuildProjectDetails({String? encryptionKey, AwsCodeBuildProjectEnvironment? environment, String? name, String? serviceRole, AwsCodeBuildProjectSource? source, AwsCodeBuildProjectVpcConfig? vpcConfig})
AwsCodeBuildProjectDetails.fromJson(Map<String, dynamic> json)
factory

Properties

encryptionKey → String?
The AWS Key Management Service (AWS KMS) customer master key (CMK) used to encrypt the build output artifacts.
final
environment → AwsCodeBuildProjectEnvironment?
Information about the build environment for this build project.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the build project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRole → String?
The ARN of the IAM role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
final
source → AwsCodeBuildProjectSource?
Information about the build input source code for this build project.
final
vpcConfig → AwsCodeBuildProjectVpcConfig?
Information about the VPC configuration that AWS CodeBuild accesses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited