AwsCodeBuildProjectEnvironment class

Information about the build environment for this build project.

Constructors

AwsCodeBuildProjectEnvironment({String? certificate, String? imagePullCredentialsType, AwsCodeBuildProjectEnvironmentRegistryCredential? registryCredential, String? type})
AwsCodeBuildProjectEnvironment.fromJson(Map<String, dynamic> json)
factory

Properties

certificate → String?
The certificate to use with this build project.
final
hashCode → int
The hash code for this object.
no setterinherited
imagePullCredentialsType → String?
The type of credentials AWS CodeBuild uses to pull images in your build.
final
registryCredential → AwsCodeBuildProjectEnvironmentRegistryCredential?
The credentials for access to a private registry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of build environment to use for related builds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited