AwsCodeBuildProjectEnvironmentRegistryCredential class

The credentials for access to a private registry.

Properties

credential → String?
The Amazon Resource Name (ARN) or name of credentials created using AWS Secrets Manager.
final
credentialProvider → String?
The service that created the credentials to access a private Docker registry.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited