AwsCodeBuildProjectSource class

Information about the build input source code for this build project.

Constructors

AwsCodeBuildProjectSource({int? gitCloneDepth, bool? insecureSsl, String? location, String? type})
AwsCodeBuildProjectSource.fromJson(Map<String, dynamic> json)
factory

Properties

gitCloneDepth → int?
Information about the Git clone depth for the build project.
final
hashCode → int
The hash code for this object.
no setterinherited
insecureSsl → bool?
Whether to ignore SSL warnings while connecting to the project source code.
final
location → String?
Information about the location of the source code to be built.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of repository that contains the source code to be built. Valid values are:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited