AwsCorsConfiguration class

Contains the cross-origin resource sharing (CORS) configuration for the API. CORS is only supported for HTTP APIs.

Constructors

AwsCorsConfiguration({bool? allowCredentials, List<String>? allowHeaders, List<String>? allowMethods, List<String>? allowOrigins, List<String>? exposeHeaders, int? maxAge})
AwsCorsConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

allowCredentials → bool?
Indicates whether the CORS request includes credentials.
final
allowHeaders → List<String>?
The allowed headers for CORS requests.
final
allowMethods → List<String>?
The allowed methods for CORS requests.
final
allowOrigins → List<String>?
The allowed origins for CORS requests.
final
exposeHeaders → List<String>?
The exposed headers for CORS requests.
final
hashCode → int
The hash code for this object.
no setterinherited
maxAge → int?
The number of seconds for which the browser caches preflight request results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited