AwsDynamoDbTableBillingModeSummary class

Provides information about the billing for read/write capacity on the table.

Constructors

AwsDynamoDbTableBillingModeSummary({String? billingMode, String? lastUpdateToPayPerRequestDateTime})
AwsDynamoDbTableBillingModeSummary.fromJson(Map<String, dynamic> json)
factory

Properties

billingMode → String?
The method used to charge for read and write throughput and to manage capacity.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateToPayPerRequestDateTime → String?
If the billing mode is PAY_PER_REQUEST, indicates when the billing mode was set to that value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited