AwsDynamoDbTableDetails class

Provides details about a DynamoDB table.

Constructors

AwsDynamoDbTableDetails({List<AwsDynamoDbTableAttributeDefinition>? attributeDefinitions, AwsDynamoDbTableBillingModeSummary? billingModeSummary, String? creationDateTime, List<AwsDynamoDbTableGlobalSecondaryIndex>? globalSecondaryIndexes, String? globalTableVersion, int? itemCount, List<AwsDynamoDbTableKeySchema>? keySchema, String? latestStreamArn, String? latestStreamLabel, List<AwsDynamoDbTableLocalSecondaryIndex>? localSecondaryIndexes, AwsDynamoDbTableProvisionedThroughput? provisionedThroughput, List<AwsDynamoDbTableReplica>? replicas, AwsDynamoDbTableRestoreSummary? restoreSummary, AwsDynamoDbTableSseDescription? sseDescription, AwsDynamoDbTableStreamSpecification? streamSpecification, String? tableId, String? tableName, int? tableSizeBytes, String? tableStatus})
AwsDynamoDbTableDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attributeDefinitions → List<AwsDynamoDbTableAttributeDefinition>?
A list of attribute definitions for the table.
final
billingModeSummary → AwsDynamoDbTableBillingModeSummary?
Information about the billing for read/write capacity on the table.
final
creationDateTime → String?
Indicates when the table was created.
final
globalSecondaryIndexes → List<AwsDynamoDbTableGlobalSecondaryIndex>?
List of global secondary indexes for the table.
final
globalTableVersion → String?
The version of global tables being used.
final
hashCode → int
The hash code for this object.
no setterinherited
itemCount → int?
The number of items in the table.
final
keySchema → List<AwsDynamoDbTableKeySchema>?
The primary key structure for the table.
final
latestStreamArn → String?
The ARN of the latest stream for the table.
final
latestStreamLabel → String?
The label of the latest stream. The label is not a unique identifier.
final
localSecondaryIndexes → List<AwsDynamoDbTableLocalSecondaryIndex>?
The list of local secondary indexes for the table.
final
provisionedThroughput → AwsDynamoDbTableProvisionedThroughput?
Information about the provisioned throughput for the table.
final
replicas → List<AwsDynamoDbTableReplica>?
The list of replicas of this table.
final
restoreSummary → AwsDynamoDbTableRestoreSummary?
Information about the restore for the table.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sseDescription → AwsDynamoDbTableSseDescription?
Information about the server-side encryption for the table.
final
streamSpecification → AwsDynamoDbTableStreamSpecification?
The current DynamoDB Streams configuration for the table.
final
tableId → String?
The identifier of the table.
final
tableName → String?
The name of the table.
final
tableSizeBytes → int?
The total size of the table in bytes.
final
tableStatus → String?
The current status of the table.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited