AwsDynamoDbTableGlobalSecondaryIndex class

Information abut a global secondary index for the table.

Constructors

AwsDynamoDbTableGlobalSecondaryIndex({bool? backfilling, String? indexArn, String? indexName, int? indexSizeBytes, String? indexStatus, int? itemCount, List<AwsDynamoDbTableKeySchema>? keySchema, AwsDynamoDbTableProjection? projection, AwsDynamoDbTableProvisionedThroughput? provisionedThroughput})
AwsDynamoDbTableGlobalSecondaryIndex.fromJson(Map<String, dynamic> json)
factory

Properties

backfilling → bool?
Whether the index is currently backfilling.
final
hashCode → int
The hash code for this object.
no setterinherited
indexArn → String?
The ARN of the index.
final
indexName → String?
The name of the index.
final
indexSizeBytes → int?
The total size in bytes of the index.
final
indexStatus → String?
The current status of the index.
final
itemCount → int?
The number of items in the index.
final
keySchema → List<AwsDynamoDbTableKeySchema>?
The key schema for the index.
final
projection → AwsDynamoDbTableProjection?
Attributes that are copied from the table into an index.
final
provisionedThroughput → AwsDynamoDbTableProvisionedThroughput?
Information about the provisioned throughput settings for the indexes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited