AwsDynamoDbTableKeySchema class

A component of the key schema for the DynamoDB table, a global secondary index, or a local secondary index.

Constructors

AwsDynamoDbTableKeySchema({String? attributeName, String? keyType})
AwsDynamoDbTableKeySchema.fromJson(Map<String, dynamic> json)
factory

Properties

attributeName → String?
The name of the key schema attribute.
final
hashCode → int
The hash code for this object.
no setterinherited
keyType → String?
The type of key used for the key schema attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited