AwsDynamoDbTableLocalSecondaryIndex class

Information about a local secondary index for a DynamoDB table.

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexArn → String?
The ARN of the index.
final
indexName → String?
The name of the index.
final
keySchema → List<AwsDynamoDbTableKeySchema>?
The complete key schema for the index.
final
projection → AwsDynamoDbTableProjection?
Attributes that are copied from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited