AwsDynamoDbTableProjection class

For global and local secondary indexes, identifies the attributes that are copied from the table into the index.

Constructors

AwsDynamoDbTableProjection({List<String>? nonKeyAttributes, String? projectionType})
AwsDynamoDbTableProjection.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nonKeyAttributes → List<String>?
The nonkey attributes that are projected into the index. For each attribute, provide the attribute name.
final
projectionType → String?
The types of attributes that are projected into the index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited