AwsDynamoDbTableProvisionedThroughput class

Information about the provisioned throughput for the table or for a global secondary index.

Constructors

AwsDynamoDbTableProvisionedThroughput({String? lastDecreaseDateTime, String? lastIncreaseDateTime, int? numberOfDecreasesToday, int? readCapacityUnits, int? writeCapacityUnits})
AwsDynamoDbTableProvisionedThroughput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastDecreaseDateTime → String?
Indicates when the provisioned throughput was last decreased.
final
lastIncreaseDateTime → String?
Indicates when the provisioned throughput was last increased.
final
numberOfDecreasesToday → int?
The number of times during the current UTC calendar day that the provisioned throughput was decreased.
final
readCapacityUnits → int?
The maximum number of strongly consistent reads consumed per second before DynamoDB returns a ThrottlingException.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeCapacityUnits → int?
The maximum number of writes consumed per second before DynamoDB returns a ThrottlingException.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited