AwsDynamoDbTableProvisionedThroughputOverride class

Replica-specific configuration for the provisioned throughput.

Properties

hashCode → int
The hash code for this object.
no setterinherited
readCapacityUnits → int?
The read capacity units for the replica.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited