AwsDynamoDbTableReplica class

Information about a replica of a DynamoDB table.

Constructors

AwsDynamoDbTableReplica({List<AwsDynamoDbTableReplicaGlobalSecondaryIndex>? globalSecondaryIndexes, String? kmsMasterKeyId, AwsDynamoDbTableProvisionedThroughputOverride? provisionedThroughputOverride, String? regionName, String? replicaStatus, String? replicaStatusDescription})
AwsDynamoDbTableReplica.fromJson(Map<String, dynamic> json)
factory

Properties

globalSecondaryIndexes → List<AwsDynamoDbTableReplicaGlobalSecondaryIndex>?
List of global secondary indexes for the replica.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsMasterKeyId → String?
The identifier of the AWS KMS customer master key (CMK) that will be used for AWS KMS encryption for the replica.
final
provisionedThroughputOverride → AwsDynamoDbTableProvisionedThroughputOverride?
Replica-specific configuration for the provisioned throughput.
final
regionName → String?
The name of the Region where the replica is located.
final
replicaStatus → String?
The current status of the replica.
final
replicaStatusDescription → String?
Detailed information about the replica status.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited