AwsDynamoDbTableRestoreSummary class

Information about the restore for the table.

Constructors

AwsDynamoDbTableRestoreSummary({String? restoreDateTime, bool? restoreInProgress, String? sourceBackupArn, String? sourceTableArn})
AwsDynamoDbTableRestoreSummary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
restoreDateTime → String?
Indicates the point in time that the table was restored to.
final
restoreInProgress → bool?
Whether a restore is currently in progress.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceBackupArn → String?
The ARN of the source backup from which the table was restored.
final
sourceTableArn → String?
The ARN of the source table for the backup.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited