AwsDynamoDbTableSseDescription class

Information about the server-side encryption for the table.

Constructors

AwsDynamoDbTableSseDescription({String? inaccessibleEncryptionDateTime, String? kmsMasterKeyArn, String? sseType, String? status})
AwsDynamoDbTableSseDescription.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inaccessibleEncryptionDateTime → String?
If the key is inaccessible, the date and time when DynamoDB detected that the key was inaccessible.
final
kmsMasterKeyArn → String?
The ARN of the AWS KMS customer master key (CMK) that is used for the AWS KMS encryption.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sseType → String?
The type of server-side encryption.
final
status → String?
The status of the server-side encryption.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited