AwsDynamoDbTableStreamSpecification class

The current DynamoDB Streams configuration for the table.

Constructors

AwsDynamoDbTableStreamSpecification({bool? streamEnabled, String? streamViewType})
AwsDynamoDbTableStreamSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamEnabled → bool?
Indicates whether DynamoDB Streams is enabled on the table.
final
streamViewType → String?
Determines the information that is written to the table.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited