AwsEc2EipDetails class

Information about an Elastic IP address.

Constructors

AwsEc2EipDetails({String? allocationId, String? associationId, String? domain, String? instanceId, String? networkBorderGroup, String? networkInterfaceId, String? networkInterfaceOwnerId, String? privateIpAddress, String? publicIp, String? publicIpv4Pool})
AwsEc2EipDetails.fromJson(Map<String, dynamic> json)
factory

Properties

allocationId → String?
The identifier that AWS assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
final
associationId → String?
The identifier that represents the association of the Elastic IP address with an EC2 instance.
final
domain → String?
The domain in which to allocate the address.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String?
The identifier of the EC2 instance.
final
networkBorderGroup → String?
The name of the location from which the Elastic IP address is advertised.
final
networkInterfaceId → String?
The identifier of the network interface.
final
networkInterfaceOwnerId → String?
The AWS account ID of the owner of the network interface.
final
privateIpAddress → String?
The private IP address that is associated with the Elastic IP address.
final
publicIp → String?
A public IP address that is associated with the EC2 instance.
final
publicIpv4Pool → String?
The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited