AwsEc2InstanceDetails class

The details of an Amazon EC2 instance.

Constructors

AwsEc2InstanceDetails({String? iamInstanceProfileArn, String? imageId, List<String>? ipV4Addresses, List<String>? ipV6Addresses, String? keyName, String? launchedAt, String? subnetId, String? type, String? vpcId})
AwsEc2InstanceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iamInstanceProfileArn → String?
The IAM profile ARN of the instance.
final
imageId → String?
The Amazon Machine Image (AMI) ID of the instance.
final
ipV4Addresses → List<String>?
The IPv4 addresses associated with the instance.
final
ipV6Addresses → List<String>?
The IPv6 addresses associated with the instance.
final
keyName → String?
The key name associated with the instance.
final
launchedAt → String?
Indicates when the instance was launched.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetId → String?
The identifier of the subnet that the instance was launched in.
final
type → String?
The instance type of the instance.
final
vpcId → String?
The identifier of the VPC that the instance was launched in.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited