AwsEc2NetworkInterfaceAttachment class

Information about the network interface attachment.

Constructors

AwsEc2NetworkInterfaceAttachment({String? attachTime, String? attachmentId, bool? deleteOnTermination, int? deviceIndex, String? instanceId, String? instanceOwnerId, String? status})
AwsEc2NetworkInterfaceAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

attachmentId → String?
The identifier of the network interface attachment
final
attachTime → String?
Indicates when the attachment initiated.
final
deleteOnTermination → bool?
Indicates whether the network interface is deleted when the instance is terminated.
final
deviceIndex → int?
The device index of the network interface attachment on the instance.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String?
The ID of the instance.
final
instanceOwnerId → String?
The AWS account ID of the owner of the instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The attachment state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited