AwsEc2NetworkInterfaceDetails class

Details about the network interface

Constructors

AwsEc2NetworkInterfaceDetails({AwsEc2NetworkInterfaceAttachment? attachment, String? networkInterfaceId, List<AwsEc2NetworkInterfaceSecurityGroup>? securityGroups, bool? sourceDestCheck})
AwsEc2NetworkInterfaceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attachment → AwsEc2NetworkInterfaceAttachment?
The network interface attachment.
final
hashCode → int
The hash code for this object.
no setterinherited
networkInterfaceId → String?
The ID of the network interface.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroups → List<AwsEc2NetworkInterfaceSecurityGroup>?
Security groups for the network interface.
final
sourceDestCheck → bool?
Indicates whether traffic to or from the instance is validated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited