AwsEc2SecurityGroupDetails class

Details about an EC2 security group.

Constructors

AwsEc2SecurityGroupDetails({String? groupId, String? groupName, List<AwsEc2SecurityGroupIpPermission>? ipPermissions, List<AwsEc2SecurityGroupIpPermission>? ipPermissionsEgress, String? ownerId, String? vpcId})
AwsEc2SecurityGroupDetails.fromJson(Map<String, dynamic> json)
factory

Properties

groupId → String?
The ID of the security group.
final
groupName → String?
The name of the security group.
final
hashCode → int
The hash code for this object.
no setterinherited
ipPermissions → List<AwsEc2SecurityGroupIpPermission>?
The inbound rules associated with the security group.
final
ipPermissionsEgress → List<AwsEc2SecurityGroupIpPermission>?
VPC only The outbound rules associated with the security group.
final
ownerId → String?
The AWS account ID of the owner of the security group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcId → String?
VPC only The ID of the VPC for the security group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited