AwsEc2SecurityGroupIpRange class

A range of IPv4 addresses.

Constructors

AwsEc2SecurityGroupIpRange({String? cidrIp})
AwsEc2SecurityGroupIpRange.fromJson(Map<String, dynamic> json)
factory

Properties

cidrIp → String?
The IPv4 CIDR range. You can specify either a CIDR range or a source security group, but not both. To specify a single IPv4 address, use the /32 prefix length.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited