AwsEc2SecurityGroupIpv6Range class

A range of IPv6 addresses.

Constructors

AwsEc2SecurityGroupIpv6Range({String? cidrIpv6})
AwsEc2SecurityGroupIpv6Range.fromJson(Map<String, dynamic> json)
factory

Properties

cidrIpv6 → String?
The IPv6 CIDR range. You can specify either a CIDR range or a source security group, but not both. To specify a single IPv6 address, use the /128 prefix length.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited