AwsEc2SecurityGroupUserIdGroupPair class

A relationship between a security group and a user.

Constructors

AwsEc2SecurityGroupUserIdGroupPair({String? groupId, String? groupName, String? peeringStatus, String? userId, String? vpcId, String? vpcPeeringConnectionId})
AwsEc2SecurityGroupUserIdGroupPair.fromJson(Map<String, dynamic> json)
factory

Properties

groupId → String?
The ID of the security group.
final
groupName → String?
The name of the security group.
final
hashCode → int
The hash code for this object.
no setterinherited
peeringStatus → String?
The status of a VPC peering connection, if applicable.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
The ID of an AWS account.
final
vpcId → String?
The ID of the VPC for the referenced security group, if applicable.
final
vpcPeeringConnectionId → String?
The ID of the VPC peering connection, if applicable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited