AwsEc2VolumeAttachment class

An attachment to an AWS EC2 volume.

Constructors

AwsEc2VolumeAttachment({String? attachTime, bool? deleteOnTermination, String? instanceId, String? status})
AwsEc2VolumeAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

attachTime → String?
The datetime when the attachment initiated.
final
deleteOnTermination → bool?
Whether the EBS volume is deleted when the EC2 instance is terminated.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String?
The identifier of the EC2 instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The attachment state of the volume.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited