AwsEc2VolumeDetails class

Details about an EC2 volume.

Constructors

AwsEc2VolumeDetails({List<AwsEc2VolumeAttachment>? attachments, String? createTime, bool? encrypted, String? kmsKeyId, int? size, String? snapshotId, String? status})
AwsEc2VolumeDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attachments → List<AwsEc2VolumeAttachment>?
The volume attachments.
final
createTime → String?
Indicates when the volume was created.
final
encrypted → bool?
Whether the volume is encrypted.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The ARN of the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to protect the volume encryption key for the volume.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
The size of the volume, in GiBs.
final
snapshotId → String?
The snapshot from which the volume was created.
final
status → String?
The volume state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited