AwsEc2VpcDetails class

Details about an EC2 VPC.

Constructors

AwsEc2VpcDetails({List<CidrBlockAssociation>? cidrBlockAssociationSet, String? dhcpOptionsId, List<Ipv6CidrBlockAssociation>? ipv6CidrBlockAssociationSet, String? state})
AwsEc2VpcDetails.fromJson(Map<String, dynamic> json)
factory

Properties

cidrBlockAssociationSet → List<CidrBlockAssociation>?
Information about the IPv4 CIDR blocks associated with the VPC.
final
dhcpOptionsId → String?
The identifier of the set of Dynamic Host Configuration Protocol (DHCP) options that are associated with the VPC. If the default options are associated with the VPC, then this is default.
final
hashCode → int
The hash code for this object.
no setterinherited
ipv6CidrBlockAssociationSet → List<Ipv6CidrBlockAssociation>?
Information about the IPv6 CIDR blocks associated with the VPC.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
The current state of the VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited