AwsElasticsearchDomainDetails class

Information about an Elasticsearch domain.

Constructors

AwsElasticsearchDomainDetails({String? accessPolicies, AwsElasticsearchDomainDomainEndpointOptions? domainEndpointOptions, String? domainId, String? domainName, String? elasticsearchVersion, AwsElasticsearchDomainEncryptionAtRestOptions? encryptionAtRestOptions, String? endpoint, Map<String, String>? endpoints, AwsElasticsearchDomainNodeToNodeEncryptionOptions? nodeToNodeEncryptionOptions, AwsElasticsearchDomainVPCOptions? vPCOptions})
AwsElasticsearchDomainDetails.fromJson(Map<String, dynamic> json)
factory

Properties

accessPolicies → String?
IAM policy document specifying the access policies for the new Amazon ES domain.
final
domainEndpointOptions → AwsElasticsearchDomainDomainEndpointOptions?
Additional options for the domain endpoint.
final
domainId → String?
Unique identifier for an Amazon ES domain.
final
domainName → String?
Name of an Amazon ES domain.
final
elasticsearchVersion → String?
Elasticsearch version.
final
encryptionAtRestOptions → AwsElasticsearchDomainEncryptionAtRestOptions?
Details about the configuration for encryption at rest.
final
endpoint → String?
Domain-specific endpoint used to submit index, search, and data upload requests to an Amazon ES domain.
final
endpoints → Map<String, String>?
The key-value pair that exists if the Amazon ES domain uses VPC endpoints.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeToNodeEncryptionOptions → AwsElasticsearchDomainNodeToNodeEncryptionOptions?
Details about the configuration for node-to-node encryption.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vPCOptions → AwsElasticsearchDomainVPCOptions?
Information that Amazon ES derives based on VPCOptions for the domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited