AwsElasticsearchDomainEncryptionAtRestOptions class

Details about the configuration for encryption at rest.

Properties

enabled → bool?
Whether encryption at rest is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The KMS key ID. Takes the form 1a2a3a4-1a2a-3a4a-5a6a-1a2a3a4a5a6a.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited