AwsElasticsearchDomainVPCOptions class

Information that Amazon ES derives based on VPCOptions for the domain.

Constructors

AwsElasticsearchDomainVPCOptions({List<String>? availabilityZones, List<String>? securityGroupIds, List<String>? subnetIds, String? vPCId})
AwsElasticsearchDomainVPCOptions.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZones → List<String>?
The list of Availability Zones associated with the VPC subnets.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → List<String>?
The list of security group IDs associated with the VPC endpoints for the domain.
final
subnetIds → List<String>?
A list of subnet IDs associated with the VPC endpoints for the domain.
final
vPCId → String?
ID for the VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited