AwsElbLoadBalancerAccessLog class

Contains information about the access log configuration for the load balancer.

Constructors

AwsElbLoadBalancerAccessLog({int? emitInterval, bool? enabled, String? s3BucketName, String? s3BucketPrefix})
AwsElbLoadBalancerAccessLog.fromJson(Map<String, dynamic> json)
factory

Properties

emitInterval → int?
The interval in minutes for publishing the access logs.
final
enabled → bool?
Indicates whether access logs are enabled for the load balancer.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
The name of the S3 bucket where the access logs are stored.
final
s3BucketPrefix → String?
The logical hierarchy that was created for the S3 bucket.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited