AwsElbLoadBalancerAttributes class

Contains attributes for the load balancer.

Properties

accessLog → AwsElbLoadBalancerAccessLog?
Information about the access log configuration for the load balancer.
final
connectionDraining → AwsElbLoadBalancerConnectionDraining?
Information about the connection draining configuration for the load balancer.
final
connectionSettings → AwsElbLoadBalancerConnectionSettings?
Connection settings for the load balancer.
final
crossZoneLoadBalancing → AwsElbLoadBalancerCrossZoneLoadBalancing?
Cross-zone load balancing settings for the load balancer.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited