AwsElbLoadBalancerBackendServerDescription class

Provides information about the configuration of an EC2 instance for the load balancer.

Constructors

AwsElbLoadBalancerBackendServerDescription({int? instancePort, List<String>? policyNames})
AwsElbLoadBalancerBackendServerDescription.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instancePort → int?
The port on which the EC2 instance is listening.
final
policyNames → List<String>?
The names of the policies that are enabled for the EC2 instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited