AwsElbLoadBalancerConnectionDraining class

Contains information about the connection draining configuration for the load balancer.

Constructors

AwsElbLoadBalancerConnectionDraining({bool? enabled, int? timeout})
AwsElbLoadBalancerConnectionDraining.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
Indicates whether connection draining is enabled for the load balancer.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int?
The maximum time, in seconds, to keep the existing connections open before deregistering the instances.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited