AwsElbLoadBalancerDetails class

Contains details about a Classic Load Balancer.

Constructors

AwsElbLoadBalancerDetails({List<String>? availabilityZones, List<AwsElbLoadBalancerBackendServerDescription>? backendServerDescriptions, String? canonicalHostedZoneName, String? canonicalHostedZoneNameID, String? createdTime, String? dnsName, AwsElbLoadBalancerHealthCheck? healthCheck, List<AwsElbLoadBalancerInstance>? instances, List<AwsElbLoadBalancerListenerDescription>? listenerDescriptions, AwsElbLoadBalancerAttributes? loadBalancerAttributes, String? loadBalancerName, AwsElbLoadBalancerPolicies? policies, String? scheme, List<String>? securityGroups, AwsElbLoadBalancerSourceSecurityGroup? sourceSecurityGroup, List<String>? subnets, String? vpcId})
AwsElbLoadBalancerDetails.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZones → List<String>?
The list of Availability Zones for the load balancer.
final
backendServerDescriptions → List<AwsElbLoadBalancerBackendServerDescription>?
Information about the configuration of the EC2 instances.
final
canonicalHostedZoneName → String?
The name of the Amazon Route 53 hosted zone for the load balancer.
final
canonicalHostedZoneNameID → String?
The ID of the Amazon Route 53 hosted zone for the load balancer.
final
createdTime → String?
Indicates when the load balancer was created.
final
dnsName → String?
The DNS name of the load balancer.
final
hashCode → int
The hash code for this object.
no setterinherited
healthCheck → AwsElbLoadBalancerHealthCheck?
Information about the health checks that are conducted on the load balancer.
final
instances → List<AwsElbLoadBalancerInstance>?
List of EC2 instances for the load balancer.
final
listenerDescriptions → List<AwsElbLoadBalancerListenerDescription>?
The policies that are enabled for the load balancer listeners.
final
loadBalancerAttributes → AwsElbLoadBalancerAttributes?
The attributes for a load balancer.
final
loadBalancerName → String?
The name of the load balancer.
final
policies → AwsElbLoadBalancerPolicies?
The policies for a load balancer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
The type of load balancer. Only provided if the load balancer is in a VPC.
final
securityGroups → List<String>?
The security groups for the load balancer. Only provided if the load balancer is in a VPC.
final
sourceSecurityGroup → AwsElbLoadBalancerSourceSecurityGroup?
Information about the security group for the load balancer. This is the security group that is used for inbound rules.
final
subnets → List<String>?
The list of subnet identifiers for the load balancer.
final
vpcId → String?
The identifier of the VPC for the load balancer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited