AwsElbLoadBalancerHealthCheck class

Contains information about the health checks that are conducted on the load balancer.

Constructors

AwsElbLoadBalancerHealthCheck({int? healthyThreshold, int? interval, String? target, int? timeout, int? unhealthyThreshold})
AwsElbLoadBalancerHealthCheck.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthyThreshold → int?
The number of consecutive health check successes required before the instance is moved to the Healthy state.
final
interval → int?
The approximate interval, in seconds, between health checks of an individual instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
The instance that is being checked. The target specifies the protocol and port. The available protocols are TCP, SSL, HTTP, and HTTPS. The range of valid ports is 1 through 65535.
final
timeout → int?
The amount of time, in seconds, during which no response means a failed health check.
final
unhealthyThreshold → int?
The number of consecutive health check failures that must occur before the instance is moved to the Unhealthy state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited