AwsElbLoadBalancerSourceSecurityGroup class

Contains information about the security group for the load balancer.

Constructors

AwsElbLoadBalancerSourceSecurityGroup({String? groupName, String? ownerAlias})
AwsElbLoadBalancerSourceSecurityGroup.fromJson(Map<String, dynamic> json)
factory

Properties

groupName → String?
The name of the security group.
final
hashCode → int
The hash code for this object.
no setterinherited
ownerAlias → String?
The owner of the security group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited