AwsElbv2LoadBalancerDetails class

Information about a load balancer.

Constructors

AwsElbv2LoadBalancerDetails({List<AvailabilityZone>? availabilityZones, String? canonicalHostedZoneId, String? createdTime, String? dNSName, String? ipAddressType, String? scheme, List<String>? securityGroups, LoadBalancerState? state, String? type, String? vpcId})
AwsElbv2LoadBalancerDetails.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZones → List<AvailabilityZone>?
The Availability Zones for the load balancer.
final
canonicalHostedZoneId → String?
The ID of the Amazon Route 53 hosted zone associated with the load balancer.
final
createdTime → String?
Indicates when the load balancer was created.
final
dNSName → String?
The public DNS name of the load balancer.
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddressType → String?
The type of IP addresses used by the subnets for your load balancer. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
The nodes of an Internet-facing load balancer have public IP addresses.
final
securityGroups → List<String>?
The IDs of the security groups for the load balancer.
final
state → LoadBalancerState?
The state of the load balancer.
final
type → String?
The type of load balancer.
final
vpcId → String?
The ID of the VPC for the load balancer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited