AwsIamAccessKeyDetails class

IAM access key details related to a finding.

Constructors

AwsIamAccessKeyDetails({String? accessKeyId, String? accountId, String? createdAt, String? principalId, String? principalName, String? principalType, AwsIamAccessKeySessionContext? sessionContext, AwsIamAccessKeyStatus? status, String? userName})
AwsIamAccessKeyDetails.fromJson(Map<String, dynamic> json)
factory

Properties

accessKeyId → String?
The identifier of the access key.
final
accountId → String?
The AWS account ID of the account for the key.
final
createdAt → String?
Indicates when the IAM access key was created.
final
hashCode → int
The hash code for this object.
no setterinherited
principalId → String?
The ID of the principal associated with an access key.
final
principalName → String?
The name of the principal.
final
principalType → String?
The type of principal associated with an access key.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionContext → AwsIamAccessKeySessionContext?
Information about the session that the key was used for.
final
status → AwsIamAccessKeyStatus?
The status of the IAM access key related to a finding.
final
userName → String?
The user associated with the IAM access key related to a finding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited