AwsIamAccessKeySessionContextSessionIssuer class

Information about the entity that created the session.

Constructors

AwsIamAccessKeySessionContextSessionIssuer({String? accountId, String? arn, String? principalId, String? type, String? userName})
AwsIamAccessKeySessionContextSessionIssuer.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The identifier of the AWS account that created the session.
final
arn → String?
The ARN of the session.
final
hashCode → int
The hash code for this object.
no setterinherited
principalId → String?
The principal ID of the principal (user, role, or group) that created the session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of principal (user, role, or group) that created the session.
final
userName → String?
The name of the principal that created the session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited