AwsIamGroupDetails class

Contains details about an IAM group.

Constructors

AwsIamGroupDetails({List<AwsIamAttachedManagedPolicy>? attachedManagedPolicies, String? createDate, String? groupId, String? groupName, List<AwsIamGroupPolicy>? groupPolicyList, String? path})
AwsIamGroupDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attachedManagedPolicies → List<AwsIamAttachedManagedPolicy>?
A list of the managed policies that are attached to the IAM group.
final
createDate → String?
Indicates when the IAM group was created.
final
groupId → String?
The identifier of the IAM group.
final
groupName → String?
The name of the IAM group.
final
groupPolicyList → List<AwsIamGroupPolicy>?
The list of inline policies that are embedded in the group.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String?
The path to the group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited