AwsIamInstanceProfile class

Information about an instance profile.

Constructors

AwsIamInstanceProfile({String? arn, String? createDate, String? instanceProfileId, String? instanceProfileName, String? path, List<AwsIamInstanceProfileRole>? roles})
AwsIamInstanceProfile.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the instance profile.
final
createDate → String?
Indicates when the instance profile was created.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceProfileId → String?
The identifier of the instance profile.
final
instanceProfileName → String?
The name of the instance profile.
final
path → String?
The path to the instance profile.
final
roles → List<AwsIamInstanceProfileRole>?
The roles associated with the instance profile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited