AwsIamInstanceProfileRole class

Information about a role associated with an instance profile.

Constructors

AwsIamInstanceProfileRole({String? arn, String? assumeRolePolicyDocument, String? createDate, String? path, String? roleId, String? roleName})
AwsIamInstanceProfileRole.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the role.
final
assumeRolePolicyDocument → String?
The policy that grants an entity permission to assume the role.
final
createDate → String?
Indicates when the role was created.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String?
The path to the role.
final
roleId → String?
The identifier of the role.
final
roleName → String?
The name of the role.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited