AwsIamPermissionsBoundary class

Information about the policy used to set the permissions boundary for an IAM principal.

Constructors

AwsIamPermissionsBoundary({String? permissionsBoundaryArn, String? permissionsBoundaryType})
AwsIamPermissionsBoundary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
permissionsBoundaryArn → String?
The ARN of the policy used to set the permissions boundary.
final
permissionsBoundaryType → String?
The usage type for the permissions boundary.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited