AwsIamPolicyDetails class

Represents an IAM permissions policy.

Constructors

AwsIamPolicyDetails({int? attachmentCount, String? createDate, String? defaultVersionId, String? description, bool? isAttachable, String? path, int? permissionsBoundaryUsageCount, String? policyId, String? policyName, List<AwsIamPolicyVersion>? policyVersionList, String? updateDate})
AwsIamPolicyDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attachmentCount → int?
The number of users, groups, and roles that the policy is attached to.
final
createDate → String?
When the policy was created.
final
defaultVersionId → String?
The identifier of the default version of the policy.
final
description → String?
A description of the policy.
final
hashCode → int
The hash code for this object.
no setterinherited
isAttachable → bool?
Whether the policy can be attached to a user, group, or role.
final
path → String?
The path to the policy.
final
permissionsBoundaryUsageCount → int?
The number of users and roles that use the policy to set the permissions boundary.
final
policyId → String?
The unique identifier of the policy.
final
policyName → String?
The name of the policy.
final
policyVersionList → List<AwsIamPolicyVersion>?
List of versions of the policy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateDate → String?
When the policy was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited