AwsIamPolicyVersion class

A version of an IAM policy.

Constructors

AwsIamPolicyVersion({String? createDate, bool? isDefaultVersion, String? versionId})
AwsIamPolicyVersion.fromJson(Map<String, dynamic> json)
factory

Properties

createDate → String?
Indicates when the version was created.
final
hashCode → int
The hash code for this object.
no setterinherited
isDefaultVersion → bool?
Whether the version is the default version.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String?
The identifier of the policy version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited