AwsIamRoleDetails class

Contains information about an IAM role, including all of the role's policies.

Constructors

AwsIamRoleDetails({String? assumeRolePolicyDocument, List<AwsIamAttachedManagedPolicy>? attachedManagedPolicies, String? createDate, List<AwsIamInstanceProfile>? instanceProfileList, int? maxSessionDuration, String? path, AwsIamPermissionsBoundary? permissionsBoundary, String? roleId, String? roleName, List<AwsIamRolePolicy>? rolePolicyList})
AwsIamRoleDetails.fromJson(Map<String, dynamic> json)
factory

Properties

assumeRolePolicyDocument → String?
The trust policy that grants permission to assume the role.
final
attachedManagedPolicies → List<AwsIamAttachedManagedPolicy>?
The list of the managed policies that are attached to the role.
final
createDate → String?
Indicates when the role was created.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceProfileList → List<AwsIamInstanceProfile>?
The list of instance profiles that contain this role.
final
maxSessionDuration → int?
The maximum session duration (in seconds) that you want to set for the specified role.
final
path → String?
The path to the role.
final
permissionsBoundary → AwsIamPermissionsBoundary?
final
roleId → String?
The stable and unique string identifying the role.
final
roleName → String?
The friendly name that identifies the role.
final
rolePolicyList → List<AwsIamRolePolicy>?
The list of inline policies that are embedded in the role.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited