AwsIamUserDetails class

Information about an IAM user.

Constructors

AwsIamUserDetails({List<AwsIamAttachedManagedPolicy>? attachedManagedPolicies, String? createDate, List<String>? groupList, String? path, AwsIamPermissionsBoundary? permissionsBoundary, String? userId, String? userName, List<AwsIamUserPolicy>? userPolicyList})
AwsIamUserDetails.fromJson(Map<String, dynamic> json)
factory

Properties

attachedManagedPolicies → List<AwsIamAttachedManagedPolicy>?
A list of the managed policies that are attached to the user.
final
createDate → String?
Indicates when the user was created.
final
groupList → List<String>?
A list of IAM groups that the user belongs to.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String?
The path to the user.
final
permissionsBoundary → AwsIamPermissionsBoundary?
The permissions boundary for the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
The unique identifier for the user.
final
userName → String?
The name of the user.
final
userPolicyList → List<AwsIamUserPolicy>?
The list of inline policies that are embedded in the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited