AwsKmsKeyDetails class

Contains metadata about a customer master key (CMK).

Constructors

AwsKmsKeyDetails({String? awsAccountId, double? creationDate, String? description, String? keyId, String? keyManager, String? keyState, String? origin})
AwsKmsKeyDetails.fromJson(Map<String, dynamic> json)
factory

Properties

awsAccountId → String?
The twelve-digit account ID of the AWS account that owns the CMK.
final
creationDate → double?
Indicates when the CMK was created.
final
description → String?
A description of the key.
final
hashCode → int
The hash code for this object.
no setterinherited
keyId → String?
The globally unique identifier for the CMK.
final
keyManager → String?
The manager of the CMK. CMKs in your AWS account are either customer managed or AWS managed.
final
keyState → String?
The state of the CMK.
final
origin → String?
The source of the CMK's key material.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited