AwsLambdaFunctionDetails class

Details about a function's configuration.

Constructors

AwsLambdaFunctionDetails({AwsLambdaFunctionCode? code, String? codeSha256, AwsLambdaFunctionDeadLetterConfig? deadLetterConfig, AwsLambdaFunctionEnvironment? environment, String? functionName, String? handler, String? kmsKeyArn, String? lastModified, List<AwsLambdaFunctionLayer>? layers, String? masterArn, int? memorySize, String? revisionId, String? role, String? runtime, int? timeout, AwsLambdaFunctionTracingConfig? tracingConfig, String? version, AwsLambdaFunctionVpcConfig? vpcConfig})
AwsLambdaFunctionDetails.fromJson(Map<String, dynamic> json)
factory

Properties

code → AwsLambdaFunctionCode?
An AwsLambdaFunctionCode object.
final
codeSha256 → String?
The SHA256 hash of the function's deployment package.
final
deadLetterConfig → AwsLambdaFunctionDeadLetterConfig?
The function's dead letter queue.
final
environment → AwsLambdaFunctionEnvironment?
The function's environment variables.
final
functionName → String?
The name of the function.
final
handler → String?
The function that Lambda calls to begin executing your function.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyArn → String?
The KMS key that's used to encrypt the function's environment variables. This key is only returned if you've configured a customer managed CMK.
final
lastModified → String?
Indicates when the function was last updated.
final
layers → List<AwsLambdaFunctionLayer>?
The function's layers.
final
masterArn → String?
For Lambda@Edge functions, the ARN of the master function.
final
memorySize → int?
The memory that's allocated to the function.
final
revisionId → String?
The latest updated revision of the function or alias.
final
role → String?
The function's execution role.
final
runtime → String?
The runtime environment for the Lambda function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int?
The amount of time that Lambda allows a function to run before stopping it.
final
tracingConfig → AwsLambdaFunctionTracingConfig?
The function's AWS X-Ray tracing configuration.
final
version → String?
The version of the Lambda function.
final
vpcConfig → AwsLambdaFunctionVpcConfig?
The function's networking configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited