AwsLambdaLayerVersionDetails class

Details about a Lambda layer version.

Constructors

AwsLambdaLayerVersionDetails({List<String>? compatibleRuntimes, String? createdDate, int? version})
AwsLambdaLayerVersionDetails.fromJson(Map<String, dynamic> json)
factory

Properties

compatibleRuntimes → List<String>?
The layer's compatible runtimes. Maximum number of five items.
final
createdDate → String?
Indicates when the version was created.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
The version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited