AwsRdsDbClusterDetails class

Information about an Amazon RDS DB cluster.

Constructors

AwsRdsDbClusterDetails({String? activityStreamStatus, int? allocatedStorage, List<AwsRdsDbClusterAssociatedRole>? associatedRoles, List<String>? availabilityZones, int? backupRetentionPeriod, String? clusterCreateTime, bool? copyTagsToSnapshot, bool? crossAccountClone, List<String>? customEndpoints, String? databaseName, String? dbClusterIdentifier, List<AwsRdsDbClusterMember>? dbClusterMembers, List<AwsRdsDbClusterOptionGroupMembership>? dbClusterOptionGroupMemberships, String? dbClusterParameterGroup, String? dbClusterResourceId, String? dbSubnetGroup, bool? deletionProtection, List<AwsRdsDbDomainMembership>? domainMemberships, List<String>? enabledCloudWatchLogsExports, String? endpoint, String? engine, String? engineMode, String? engineVersion, String? hostedZoneId, bool? httpEndpointEnabled, bool? iamDatabaseAuthenticationEnabled, String? kmsKeyId, String? masterUsername, bool? multiAz, int? port, String? preferredBackupWindow, String? preferredMaintenanceWindow, List<String>? readReplicaIdentifiers, String? readerEndpoint, String? status, bool? storageEncrypted, List<AwsRdsDbInstanceVpcSecurityGroup>? vpcSecurityGroups})
AwsRdsDbClusterDetails.fromJson(Map<String, dynamic> json)
factory

Properties

activityStreamStatus → String?
The status of the database activity stream.
final
allocatedStorage → int?
For all database engines except Aurora, specifies the allocated storage size in gibibytes (GiB).
final
associatedRoles → List<AwsRdsDbClusterAssociatedRole>?
A list of the IAM roles that are associated with the DB cluster.
final
availabilityZones → List<String>?
A list of Availability Zones (AZs) where instances in the DB cluster can be created.
final
backupRetentionPeriod → int?
The number of days for which automated backups are retained.
final
clusterCreateTime → String?
Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).
final
copyTagsToSnapshot → bool?
Whether tags are copied from the DB cluster to snapshots of the DB cluster.
final
crossAccountClone → bool?
Whether the DB cluster is a clone of a DB cluster owned by a different AWS account.
final
customEndpoints → List<String>?
A list of custom endpoints for the DB cluster.
final
databaseName → String?
The name of the database.
final
dbClusterIdentifier → String?
The DB cluster identifier that the user assigned to the cluster. This identifier is the unique key that identifies a DB cluster.
final
dbClusterMembers → List<AwsRdsDbClusterMember>?
The list of instances that make up the DB cluster.
final
dbClusterOptionGroupMemberships → List<AwsRdsDbClusterOptionGroupMembership>?
The list of option group memberships for this DB cluster.
final
dbClusterParameterGroup → String?
The name of the DB cluster parameter group for the DB cluster.
final
dbClusterResourceId → String?
The identifier of the DB cluster. The identifier must be unique within each AWS Region and is immutable.
final
dbSubnetGroup → String?
The subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
final
deletionProtection → bool?
Whether the DB cluster has deletion protection enabled.
final
domainMemberships → List<AwsRdsDbDomainMembership>?
The Active Directory domain membership records that are associated with the DB cluster.
final
enabledCloudWatchLogsExports → List<String>?
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
final
endpoint → String?
The connection endpoint for the primary instance of the DB cluster.
final
engine → String?
The name of the database engine to use for this DB cluster.
final
engineMode → String?
The database engine mode of the DB cluster.
final
engineVersion → String?
The version number of the database engine to use.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String?
Specifies the identifier that Amazon Route 53 assigns when you create a hosted zone.
final
httpEndpointEnabled → bool?
Whether the HTTP endpoint for an Aurora Serverless DB cluster is enabled.
final
iamDatabaseAuthenticationEnabled → bool?
Whether the mapping of IAM accounts to database accounts is enabled.
final
kmsKeyId → String?
The ARN of the AWS KMS master key that is used to encrypt the database instances in the DB cluster.
final
masterUsername → String?
The name of the master user for the DB cluster.
final
multiAz → bool?
Whether the DB cluster has instances in multiple Availability Zones.
final
port → int?
The port number on which the DB instances in the DB cluster accept connections.
final
preferredBackupWindow → String?
The range of time each day when automated backups are created, if automated backups are enabled.
final
preferredMaintenanceWindow → String?
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
final
readerEndpoint → String?
The reader endpoint for the DB cluster.
final
readReplicaIdentifiers → List<String>?
The identifiers of the read replicas that are associated with this DB cluster.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The current status of this DB cluster.
final
storageEncrypted → bool?
Whether the DB cluster is encrypted.
final
vpcSecurityGroups → List<AwsRdsDbInstanceVpcSecurityGroup>?
A list of VPC security groups that the DB cluster belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited