AwsRdsDbClusterMember class

Information about an instance in the DB cluster.

Constructors

AwsRdsDbClusterMember({String? dbClusterParameterGroupStatus, String? dbInstanceIdentifier, bool? isClusterWriter, int? promotionTier})
AwsRdsDbClusterMember.fromJson(Map<String, dynamic> json)
factory

Properties

dbClusterParameterGroupStatus → String?
The status of the DB cluster parameter group for this member of the DB cluster.
final
dbInstanceIdentifier → String?
The instance identifier for this member of the DB cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
isClusterWriter → bool?
Whether the cluster member is the primary instance for the DB cluster.
final
promotionTier → int?
Specifies the order in which an Aurora replica is promoted to the primary instance when the existing primary instance fails.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited