AwsRdsDbClusterSnapshotDetails class

Information about an Amazon RDS DB cluster snapshot.

Constructors

AwsRdsDbClusterSnapshotDetails({int? allocatedStorage, List<String>? availabilityZones, String? clusterCreateTime, String? dbClusterIdentifier, String? dbClusterSnapshotIdentifier, String? engine, String? engineVersion, bool? iamDatabaseAuthenticationEnabled, String? kmsKeyId, String? licenseModel, String? masterUsername, int? percentProgress, int? port, String? snapshotCreateTime, String? snapshotType, String? status, bool? storageEncrypted, String? vpcId})
AwsRdsDbClusterSnapshotDetails.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
Specifies the allocated storage size in gibibytes (GiB).
final
availabilityZones → List<String>?
A list of Availability Zones where instances in the DB cluster can be created.
final
clusterCreateTime → String?
Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).
final
dbClusterIdentifier → String?
The DB cluster identifier.
final
dbClusterSnapshotIdentifier → String?
The identifier of the DB cluster snapshot.
final
engine → String?
final
engineVersion → String?
The version of the database engine to use.
final
hashCode → int
The hash code for this object.
no setterinherited
iamDatabaseAuthenticationEnabled → bool?
Whether mapping of IAM accounts to database accounts is enabled.
final
kmsKeyId → String?
The ARN of the AWS KMS master key that is used to encrypt the database instances in the DB cluster.
final
licenseModel → String?
The license model information for this DB cluster snapshot.
final
masterUsername → String?
The name of the master user for the DB cluster.
final
percentProgress → int?
Specifies the percentage of the estimated data that has been transferred.
final
port → int?
The port number on which the DB instances in the DB cluster accept connections.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotCreateTime → String?
Indicates when the snapshot was taken.
final
snapshotType → String?
The type of DB cluster snapshot.
final
status → String?
The status of this DB cluster snapshot.
final
storageEncrypted → bool?
Whether the DB cluster is encrypted.
final
vpcId → String?
The VPC ID that is associated with the DB cluster snapshot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited