AwsRdsDbDomainMembership class

Information about an Active Directory domain membership record associated with the DB instance.

Constructors

AwsRdsDbDomainMembership({String? domain, String? fqdn, String? iamRoleName, String? status})
AwsRdsDbDomainMembership.fromJson(Map<String, dynamic> json)
factory

Properties

domain → String?
The identifier of the Active Directory domain.
final
fqdn → String?
The fully qualified domain name of the Active Directory domain.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleName → String?
The name of the IAM role to use when making API calls to the Directory Service.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the Active Directory Domain membership for the DB instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited