AwsRdsDbInstanceAssociatedRole class

An AWS Identity and Access Management (IAM) role associated with the DB instance.

Constructors

AwsRdsDbInstanceAssociatedRole({String? featureName, String? roleArn, String? status})
AwsRdsDbInstanceAssociatedRole.fromJson(Map<String, dynamic> json)
factory

Properties

featureName → String?
The name of the feature associated with the IAM)role.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String?
The Amazon Resource Name (ARN) of the IAM role that is associated with the DB instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Describes the state of the association between the IAM role and the DB instance. The Status property returns one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited