AwsRdsDbInstanceDetails class

Contains the details of an Amazon RDS DB instance.

Constructors

AwsRdsDbInstanceDetails({int? allocatedStorage, List<AwsRdsDbInstanceAssociatedRole>? associatedRoles, bool? autoMinorVersionUpgrade, String? availabilityZone, int? backupRetentionPeriod, String? cACertificateIdentifier, String? characterSetName, bool? copyTagsToSnapshot, String? dBClusterIdentifier, String? dBInstanceClass, String? dBInstanceIdentifier, String? dBName, int? dbInstancePort, String? dbInstanceStatus, List<AwsRdsDbParameterGroup>? dbParameterGroups, List<String>? dbSecurityGroups, AwsRdsDbSubnetGroup? dbSubnetGroup, String? dbiResourceId, bool? deletionProtection, List<AwsRdsDbDomainMembership>? domainMemberships, List<String>? enabledCloudWatchLogsExports, AwsRdsDbInstanceEndpoint? endpoint, String? engine, String? engineVersion, String? enhancedMonitoringResourceArn, bool? iAMDatabaseAuthenticationEnabled, String? instanceCreateTime, int? iops, String? kmsKeyId, String? latestRestorableTime, String? licenseModel, AwsRdsDbInstanceEndpoint? listenerEndpoint, String? masterUsername, int? maxAllocatedStorage, int? monitoringInterval, String? monitoringRoleArn, bool? multiAz, List<AwsRdsDbOptionGroupMembership>? optionGroupMemberships, AwsRdsDbPendingModifiedValues? pendingModifiedValues, bool? performanceInsightsEnabled, String? performanceInsightsKmsKeyId, int? performanceInsightsRetentionPeriod, String? preferredBackupWindow, String? preferredMaintenanceWindow, List<AwsRdsDbProcessorFeature>? processorFeatures, int? promotionTier, bool? publiclyAccessible, List<String>? readReplicaDBClusterIdentifiers, List<String>? readReplicaDBInstanceIdentifiers, String? readReplicaSourceDBInstanceIdentifier, String? secondaryAvailabilityZone, List<AwsRdsDbStatusInfo>? statusInfos, bool? storageEncrypted, String? storageType, String? tdeCredentialArn, String? timezone, List<AwsRdsDbInstanceVpcSecurityGroup>? vpcSecurityGroups})
AwsRdsDbInstanceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
The amount of storage (in gigabytes) to initially allocate for the DB instance.
final
associatedRoles → List<AwsRdsDbInstanceAssociatedRole>?
The AWS Identity and Access Management (IAM) roles associated with the DB instance.
final
autoMinorVersionUpgrade → bool?
Indicates whether minor version patches are applied automatically.
final
availabilityZone → String?
The Availability Zone where the DB instance will be created.
final
backupRetentionPeriod → int?
The number of days for which to retain automated backups.
final
cACertificateIdentifier → String?
The identifier of the CA certificate for this DB instance.
final
characterSetName → String?
The name of the character set that this DB instance is associated with.
final
copyTagsToSnapshot → bool?
Whether to copy resource tags to snapshots of the DB instance.
final
dBClusterIdentifier → String?
If the DB instance is a member of a DB cluster, contains the name of the DB cluster that the DB instance is a member of.
final
dBInstanceClass → String?
Contains the name of the compute and memory capacity class of the DB instance.
final
dBInstanceIdentifier → String?
Contains a user-supplied database identifier. This identifier is the unique key that identifies a DB instance.
final
dbInstancePort → int?
Specifies the port that the DB instance listens on. If the DB instance is part of a DB cluster, this can be a different port than the DB cluster port.
final
dbInstanceStatus → String?
The current status of the DB instance.
final
dbiResourceId → String?
The AWS Region-unique, immutable identifier for the DB instance. This identifier is found in AWS CloudTrail log entries whenever the AWS KMS key for the DB instance is accessed.
final
dBName → String?
The meaning of this parameter differs according to the database engine you use.
final
dbParameterGroups → List<AwsRdsDbParameterGroup>?
A list of the DB parameter groups to assign to the DB instance.
final
dbSecurityGroups → List<String>?
A list of the DB security groups to assign to the DB instance.
final
dbSubnetGroup → AwsRdsDbSubnetGroup?
Information about the subnet group that is associated with the DB instance.
final
deletionProtection → bool?
Indicates whether the DB instance has deletion protection enabled.
final
domainMemberships → List<AwsRdsDbDomainMembership>?
The Active Directory domain membership records associated with the DB instance.
final
enabledCloudWatchLogsExports → List<String>?
A list of log types that this DB instance is configured to export to CloudWatch Logs.
final
endpoint → AwsRdsDbInstanceEndpoint?
Specifies the connection endpoint.
final
engine → String?
Provides the name of the database engine to use for this DB instance.
final
engineVersion → String?
Indicates the database engine version.
final
enhancedMonitoringResourceArn → String?
The ARN of the CloudWatch Logs log stream that receives the enhanced monitoring metrics data for the DB instance.
final
hashCode → int
The hash code for this object.
no setterinherited
iAMDatabaseAuthenticationEnabled → bool?
True if mapping of AWS Identity and Access Management (IAM) accounts to database accounts is enabled, and otherwise false.
final
instanceCreateTime → String?
Indicates when the DB instance was created.
final
iops → int?
Specifies the provisioned IOPS (I/O operations per second) for this DB instance.
final
kmsKeyId → String?
If StorageEncrypted is true, the AWS KMS key identifier for the encrypted DB instance.
final
latestRestorableTime → String?
Specifies the latest time to which a database can be restored with point-in-time restore.
final
licenseModel → String?
License model information for this DB instance.
final
listenerEndpoint → AwsRdsDbInstanceEndpoint?
final
masterUsername → String?
The master user name of the DB instance.
final
maxAllocatedStorage → int?
The upper limit to which Amazon RDS can automatically scale the storage of the DB instance.
final
monitoringInterval → int?
The interval, in seconds, between points when enhanced monitoring metrics are collected for the DB instance.
final
monitoringRoleArn → String?
The ARN for the IAM role that permits Amazon RDS to send enhanced monitoring metrics to CloudWatch Logs.
final
multiAz → bool?
Whether the DB instance is a multiple Availability Zone deployment.
final
optionGroupMemberships → List<AwsRdsDbOptionGroupMembership>?
The list of option group memberships for this DB instance.
final
pendingModifiedValues → AwsRdsDbPendingModifiedValues?
Changes to the DB instance that are currently pending.
final
performanceInsightsEnabled → bool?
Indicates whether Performance Insights is enabled for the DB instance.
final
performanceInsightsKmsKeyId → String?
The identifier of the AWS KMS key used to encrypt the Performance Insights data.
final
performanceInsightsRetentionPeriod → int?
The number of days to retain Performance Insights data.
final
preferredBackupWindow → String?
The range of time each day when automated backups are created, if automated backups are enabled.
final
preferredMaintenanceWindow → String?
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
final
processorFeatures → List<AwsRdsDbProcessorFeature>?
The number of CPU cores and the number of threads per core for the DB instance class of the DB instance.
final
promotionTier → int?
The order in which to promote an Aurora replica to the primary instance after a failure of the existing primary instance.
final
publiclyAccessible → bool?
Specifies the accessibility options for the DB instance.
final
readReplicaDBClusterIdentifiers → List<String>?
List of identifiers of Aurora DB clusters to which the RDS DB instance is replicated as a read replica.
final
readReplicaDBInstanceIdentifiers → List<String>?
List of identifiers of the read replicas associated with this DB instance.
final
readReplicaSourceDBInstanceIdentifier → String?
If this DB instance is a read replica, contains the identifier of the source DB instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAvailabilityZone → String?
For a DB instance with multi-Availability Zone support, the name of the secondary Availability Zone.
final
statusInfos → List<AwsRdsDbStatusInfo>?
The status of a read replica. If the instance isn't a read replica, this is empty.
final
storageEncrypted → bool?
Specifies whether the DB instance is encrypted.
final
storageType → String?
The storage type for the DB instance.
final
tdeCredentialArn → String?
The ARN from the key store with which the instance is associated for TDE encryption.
final
timezone → String?
The time zone of the DB instance.
final
vpcSecurityGroups → List<AwsRdsDbInstanceVpcSecurityGroup>?
A list of VPC security groups that the DB instance belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited