AwsRdsDbInstanceEndpoint class

Specifies the connection endpoint.

Constructors

AwsRdsDbInstanceEndpoint({String? address, String? hostedZoneId, int? port})
AwsRdsDbInstanceEndpoint.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
Specifies the DNS address of the DB instance.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String?
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
final
port → int?
Specifies the port that the database engine is listening on.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited