AwsRdsDbPendingModifiedValues class

Constructors

AwsRdsDbPendingModifiedValues({int? allocatedStorage, int? backupRetentionPeriod, String? caCertificateIdentifier, String? dbInstanceClass, String? dbInstanceIdentifier, String? dbSubnetGroupName, String? engineVersion, int? iops, String? licenseModel, String? masterUserPassword, bool? multiAZ, AwsRdsPendingCloudWatchLogsExports? pendingCloudWatchLogsExports, int? port, List<AwsRdsDbProcessorFeature>? processorFeatures, String? storageType})
AwsRdsDbPendingModifiedValues.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
final
backupRetentionPeriod → int?
final
caCertificateIdentifier → String?
final
dbInstanceClass → String?
final
dbInstanceIdentifier → String?
final
dbSubnetGroupName → String?
final
engineVersion → String?
final
hashCode → int
The hash code for this object.
no setterinherited
iops → int?
final
licenseModel → String?
final
masterUserPassword → String?
final
multiAZ → bool?
final
pendingCloudWatchLogsExports → AwsRdsPendingCloudWatchLogsExports?
final
port → int?
final
processorFeatures → List<AwsRdsDbProcessorFeature>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageType → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited