AwsRdsDbSnapshotDetails class

Constructors

AwsRdsDbSnapshotDetails({int? allocatedStorage, String? availabilityZone, String? dbInstanceIdentifier, String? dbSnapshotIdentifier, String? dbiResourceId, bool? encrypted, String? engine, String? engineVersion, bool? iamDatabaseAuthenticationEnabled, String? instanceCreateTime, int? iops, String? kmsKeyId, String? licenseModel, String? masterUsername, String? optionGroupName, int? percentProgress, int? port, List<AwsRdsDbProcessorFeature>? processorFeatures, String? snapshotCreateTime, String? snapshotType, String? sourceDbSnapshotIdentifier, String? sourceRegion, String? status, String? storageType, String? tdeCredentialArn, String? timezone, String? vpcId})
AwsRdsDbSnapshotDetails.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
final
availabilityZone → String?
final
dbInstanceIdentifier → String?
final
dbiResourceId → String?
final
dbSnapshotIdentifier → String?
final
encrypted → bool?
final
engine → String?
final
engineVersion → String?
final
hashCode → int
The hash code for this object.
no setterinherited
iamDatabaseAuthenticationEnabled → bool?
final
instanceCreateTime → String?
final
iops → int?
final
kmsKeyId → String?
final
licenseModel → String?
final
masterUsername → String?
final
optionGroupName → String?
final
percentProgress → int?
final
port → int?
final
processorFeatures → List<AwsRdsDbProcessorFeature>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotCreateTime → String?
final
snapshotType → String?
final
sourceDbSnapshotIdentifier → String?
final
sourceRegion → String?
final
status → String?
final
storageType → String?
final
tdeCredentialArn → String?
final
timezone → String?
final
vpcId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited