AwsRdsDbStatusInfo class

Information about the status of a read replica.

Constructors

AwsRdsDbStatusInfo({String? message, bool? normal, String? status, String? statusType})
AwsRdsDbStatusInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
If the read replica is currently in an error state, provides the error details.
final
normal → bool?
Whether the read replica instance is operating normally.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the read replica instance.
final
statusType → String?
The type of status. For a read replica, the status type is read replication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited