AwsRdsDbSubnetGroup class

Information about the subnet group for the database instance.

Constructors

AwsRdsDbSubnetGroup({String? dbSubnetGroupArn, String? dbSubnetGroupDescription, String? dbSubnetGroupName, String? subnetGroupStatus, List<AwsRdsDbSubnetGroupSubnet>? subnets, String? vpcId})
AwsRdsDbSubnetGroup.fromJson(Map<String, dynamic> json)
factory

Properties

dbSubnetGroupArn → String?
The ARN of the subnet group.
final
dbSubnetGroupDescription → String?
The description of the subnet group.
final
dbSubnetGroupName → String?
The name of the subnet group.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetGroupStatus → String?
The status of the subnet group.
final
subnets → List<AwsRdsDbSubnetGroupSubnet>?
A list of subnets in the subnet group.
final
vpcId → String?
The VPC ID of the subnet group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited