AwsRdsDbSubnetGroupSubnet class

Information about a subnet in a subnet group.

Constructors

AwsRdsDbSubnetGroupSubnet({AwsRdsDbSubnetGroupSubnetAvailabilityZone? subnetAvailabilityZone, String? subnetIdentifier, String? subnetStatus})
AwsRdsDbSubnetGroupSubnet.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetAvailabilityZone → AwsRdsDbSubnetGroupSubnetAvailabilityZone?
Information about the Availability Zone for a subnet in the subnet group.
final
subnetIdentifier → String?
The identifier of a subnet in the subnet group.
final
subnetStatus → String?
The status of a subnet in the subnet group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited