AwsRedshiftClusterClusterParameterGroup class

A cluster parameter group that is associated with an Amazon Redshift cluster.

Constructors

AwsRedshiftClusterClusterParameterGroup({List<AwsRedshiftClusterClusterParameterStatus>? clusterParameterStatusList, String? parameterApplyStatus, String? parameterGroupName})
AwsRedshiftClusterClusterParameterGroup.fromJson(Map<String, dynamic> json)
factory

Properties

clusterParameterStatusList → List<AwsRedshiftClusterClusterParameterStatus>?
The list of parameter statuses.
final
hashCode → int
The hash code for this object.
no setterinherited
parameterApplyStatus → String?
The status of updates to the parameters.
final
parameterGroupName → String?
The name of the parameter group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited