AwsRedshiftClusterClusterSnapshotCopyStatus class

Information about a cross-Region snapshot copy.

Constructors

AwsRedshiftClusterClusterSnapshotCopyStatus({String? destinationRegion, int? manualSnapshotRetentionPeriod, int? retentionPeriod, String? snapshotCopyGrantName})
AwsRedshiftClusterClusterSnapshotCopyStatus.fromJson(Map<String, dynamic> json)
factory

Properties

destinationRegion → String?
The destination Region that snapshots are automatically copied to when cross-Region snapshot copy is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
manualSnapshotRetentionPeriod → int?
The number of days that manual snapshots are retained in the destination region after they are copied from a source region.
final
retentionPeriod → int?
The number of days to retain automated snapshots in the destination Region after they are copied from a source Region.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotCopyGrantName → String?
The name of the snapshot copy grant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited