AwsRedshiftClusterDeferredMaintenanceWindow class

A time windows during which maintenance was deferred for an Amazon Redshift cluster.

Constructors

AwsRedshiftClusterDeferredMaintenanceWindow({String? deferMaintenanceEndTime, String? deferMaintenanceIdentifier, String? deferMaintenanceStartTime})
AwsRedshiftClusterDeferredMaintenanceWindow.fromJson(Map<String, dynamic> json)
factory

Properties

deferMaintenanceEndTime → String?
The end of the time window for which maintenance was deferred.
final
deferMaintenanceIdentifier → String?
The identifier of the maintenance window.
final
deferMaintenanceStartTime → String?
The start of the time window for which maintenance was deferred.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited