AwsRedshiftClusterDetails class

Details about an Amazon Redshift cluster.

Constructors

AwsRedshiftClusterDetails({bool? allowVersionUpgrade, int? automatedSnapshotRetentionPeriod, String? availabilityZone, String? clusterAvailabilityStatus, String? clusterCreateTime, String? clusterIdentifier, List<AwsRedshiftClusterClusterNode>? clusterNodes, List<AwsRedshiftClusterClusterParameterGroup>? clusterParameterGroups, String? clusterPublicKey, String? clusterRevisionNumber, List<AwsRedshiftClusterClusterSecurityGroup>? clusterSecurityGroups, AwsRedshiftClusterClusterSnapshotCopyStatus? clusterSnapshotCopyStatus, String? clusterStatus, String? clusterSubnetGroupName, String? clusterVersion, String? dBName, List<AwsRedshiftClusterDeferredMaintenanceWindow>? deferredMaintenanceWindows, AwsRedshiftClusterElasticIpStatus? elasticIpStatus, String? elasticResizeNumberOfNodeOptions, bool? encrypted, AwsRedshiftClusterEndpoint? endpoint, bool? enhancedVpcRouting, String? expectedNextSnapshotScheduleTime, String? expectedNextSnapshotScheduleTimeStatus, AwsRedshiftClusterHsmStatus? hsmStatus, List<AwsRedshiftClusterIamRole>? iamRoles, String? kmsKeyId, String? maintenanceTrackName, int? manualSnapshotRetentionPeriod, String? masterUsername, String? nextMaintenanceWindowStartTime, String? nodeType, int? numberOfNodes, List<String>? pendingActions, AwsRedshiftClusterPendingModifiedValues? pendingModifiedValues, String? preferredMaintenanceWindow, bool? publiclyAccessible, AwsRedshiftClusterResizeInfo? resizeInfo, AwsRedshiftClusterRestoreStatus? restoreStatus, String? snapshotScheduleIdentifier, String? snapshotScheduleState, String? vpcId, List<AwsRedshiftClusterVpcSecurityGroup>? vpcSecurityGroups})
AwsRedshiftClusterDetails.fromJson(Map<String, dynamic> json)
factory

Properties

allowVersionUpgrade → bool?
Indicates whether major version upgrades are applied automatically to the cluster during the maintenance window.
final
automatedSnapshotRetentionPeriod → int?
The number of days that automatic cluster snapshots are retained.
final
availabilityZone → String?
The name of the Availability Zone in which the cluster is located.
final
clusterAvailabilityStatus → String?
The availability status of the cluster for queries. Possible values are the following:
final
clusterCreateTime → String?
Indicates when the cluster was created.
final
clusterIdentifier → String?
The unique identifier of the cluster.
final
clusterNodes → List<AwsRedshiftClusterClusterNode>?
The nodes in the cluster.
final
clusterParameterGroups → List<AwsRedshiftClusterClusterParameterGroup>?
The list of cluster parameter groups that are associated with this cluster.
final
clusterPublicKey → String?
The public key for the cluster.
final
clusterRevisionNumber → String?
The specific revision number of the database in the cluster.
final
clusterSecurityGroups → List<AwsRedshiftClusterClusterSecurityGroup>?
A list of cluster security groups that are associated with the cluster.
final
clusterSnapshotCopyStatus → AwsRedshiftClusterClusterSnapshotCopyStatus?
Information about the destination Region and retention period for the cross-Region snapshot copy.
final
clusterStatus → String?
The current status of the cluster.
final
clusterSubnetGroupName → String?
The name of the subnet group that is associated with the cluster. This parameter is valid only when the cluster is in a VPC.
final
clusterVersion → String?
The version ID of the Amazon Redshift engine that runs on the cluster.
final
dBName → String?
The name of the initial database that was created when the cluster was created.
final
deferredMaintenanceWindows → List<AwsRedshiftClusterDeferredMaintenanceWindow>?
List of time windows during which maintenance was deferred.
final
elasticIpStatus → AwsRedshiftClusterElasticIpStatus?
Information about the status of the Elastic IP (EIP) address.
final
elasticResizeNumberOfNodeOptions → String?
The number of nodes that you can use the elastic resize method to resize the cluster to.
final
encrypted → bool?
Indicates whether the data in the cluster is encrypted at rest.
final
endpoint → AwsRedshiftClusterEndpoint?
The connection endpoint.
final
enhancedVpcRouting → bool?
Indicates whether to create the cluster with enhanced VPC routing enabled.
final
expectedNextSnapshotScheduleTime → String?
Indicates when the next snapshot is expected to be taken. The cluster must have a valid snapshot schedule and have backups enabled.
final
expectedNextSnapshotScheduleTimeStatus → String?
The status of the next expected snapshot.
final
hashCode → int
The hash code for this object.
no setterinherited
hsmStatus → AwsRedshiftClusterHsmStatus?
Information about whether the Amazon Redshift cluster finished applying any changes to hardware security module (HSM) settings that were specified in a modify cluster command.
final
iamRoles → List<AwsRedshiftClusterIamRole>?
A list of IAM roles that the cluster can use to access other AWS services.
final
kmsKeyId → String?
The identifier of the AWS KMS encryption key that is used to encrypt data in the cluster.
final
maintenanceTrackName → String?
The name of the maintenance track for the cluster.
final
manualSnapshotRetentionPeriod → int?
The default number of days to retain a manual snapshot.
final
masterUsername → String?
The master user name for the cluster. This name is used to connect to the database that is specified in as the value of DBName.
final
nextMaintenanceWindowStartTime → String?
Indicates the start of the next maintenance window.
final
nodeType → String?
The node type for the nodes in the cluster.
final
numberOfNodes → int?
The number of compute nodes in the cluster.
final
pendingActions → List<String>?
A list of cluster operations that are waiting to start.
final
pendingModifiedValues → AwsRedshiftClusterPendingModifiedValues?
A list of changes to the cluster that are currently pending.
final
preferredMaintenanceWindow → String?
The weekly time range, in Universal Coordinated Time (UTC), during which system maintenance can occur.
final
publiclyAccessible → bool?
Whether the cluster can be accessed from a public network.
final
resizeInfo → AwsRedshiftClusterResizeInfo?
Information about the resize operation for the cluster.
final
restoreStatus → AwsRedshiftClusterRestoreStatus?
Information about the status of a cluster restore action. Only applies to a cluster that was created by restoring a snapshot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotScheduleIdentifier → String?
A unique identifier for the cluster snapshot schedule.
final
snapshotScheduleState → String?
The current state of the cluster snapshot schedule.
final
vpcId → String?
The identifier of the VPC that the cluster is in, if the cluster is in a VPC.
final
vpcSecurityGroups → List<AwsRedshiftClusterVpcSecurityGroup>?
The list of VPC security groups that the cluster belongs to, if the cluster is in a VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited