AwsRedshiftClusterEndpoint class

The connection endpoint for an Amazon Redshift cluster.

Constructors

AwsRedshiftClusterEndpoint({String? address, int? port})
AwsRedshiftClusterEndpoint.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
The DNS address of the cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
port → int?
The port that the database engine listens on.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited