AwsRedshiftClusterHsmStatus class

Information about whether an Amazon Redshift cluster finished applying any hardware changes to security module (HSM) settings that were specified in a modify cluster command.

Constructors

AwsRedshiftClusterHsmStatus({String? hsmClientCertificateIdentifier, String? hsmConfigurationIdentifier, String? status})
AwsRedshiftClusterHsmStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hsmClientCertificateIdentifier → String?
The name of the HSM client certificate that the Amazon Redshift cluster uses to retrieve the data encryption keys that are stored in an HSM.
final
hsmConfigurationIdentifier → String?
The name of the HSM configuration that contains the information that the Amazon Redshift cluster can use to retrieve and store keys in an HSM.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Indicates whether the Amazon Redshift cluster has finished applying any HSM settings changes specified in a modify cluster command.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited