AwsRedshiftClusterIamRole class

An IAM role that the cluster can use to access other AWS services.

Constructors

AwsRedshiftClusterIamRole({String? applyStatus, String? iamRoleArn})
AwsRedshiftClusterIamRole.fromJson(Map<String, dynamic> json)
factory

Properties

applyStatus → String?
The status of the IAM role's association with the cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleArn → String?
The ARN of the IAM role.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited