AwsRedshiftClusterPendingModifiedValues class

Changes to the Amazon Redshift cluster that are currently pending.

Constructors

AwsRedshiftClusterPendingModifiedValues({int? automatedSnapshotRetentionPeriod, String? clusterIdentifier, String? clusterType, String? clusterVersion, String? encryptionType, bool? enhancedVpcRouting, String? maintenanceTrackName, String? masterUserPassword, String? nodeType, int? numberOfNodes, bool? publiclyAccessible})
AwsRedshiftClusterPendingModifiedValues.fromJson(Map<String, dynamic> json)
factory

Properties

automatedSnapshotRetentionPeriod → int?
The pending or in-progress change to the automated snapshot retention period.
final
clusterIdentifier → String?
The pending or in-progress change to the identifier for the cluster.
final
clusterType → String?
The pending or in-progress change to the cluster type.
final
clusterVersion → String?
The pending or in-progress change to the service version.
final
encryptionType → String?
The encryption type for a cluster.
final
enhancedVpcRouting → bool?
Indicates whether to create the cluster with enhanced VPC routing enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
maintenanceTrackName → String?
The name of the maintenance track that the cluster changes to during the next maintenance window.
final
masterUserPassword → String?
The pending or in-progress change to the master user password for the cluster.
final
nodeType → String?
The pending or in-progress change to the cluster's node type.
final
numberOfNodes → int?
The pending or in-progress change to the number of nodes in the cluster.
final
publiclyAccessible → bool?
The pending or in-progress change to whether the cluster can be connected to from the public network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited