AwsRedshiftClusterResizeInfo class

Information about the resize operation for the cluster.

Constructors

AwsRedshiftClusterResizeInfo({bool? allowCancelResize, String? resizeType})
AwsRedshiftClusterResizeInfo.fromJson(Map<String, dynamic> json)
factory

Properties

allowCancelResize → bool?
Indicates whether the resize operation can be canceled.
final
hashCode → int
The hash code for this object.
no setterinherited
resizeType → String?
The type of resize operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited