AwsRedshiftClusterRestoreStatus class

Information about the status of a cluster restore action. It only applies if the cluster was created by restoring a snapshot.

Constructors

AwsRedshiftClusterRestoreStatus({double? currentRestoreRateInMegaBytesPerSecond, int? elapsedTimeInSeconds, int? estimatedTimeToCompletionInSeconds, int? progressInMegaBytes, int? snapshotSizeInMegaBytes, String? status})
AwsRedshiftClusterRestoreStatus.fromJson(Map<String, dynamic> json)
factory

Properties

currentRestoreRateInMegaBytesPerSecond → double?
The number of megabytes per second being transferred from the backup storage. Returns the average rate for a completed backup.
final
elapsedTimeInSeconds → int?
The amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish.
final
estimatedTimeToCompletionInSeconds → int?
The estimate of the time remaining before the restore is complete. Returns 0 for a completed restore.
final
hashCode → int
The hash code for this object.
no setterinherited
progressInMegaBytes → int?
The number of megabytes that were transferred from snapshot storage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotSizeInMegaBytes → int?
The size of the set of snapshot data that was used to restore the cluster.
final
status → String?
The status of the restore action.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited