AwsRedshiftClusterVpcSecurityGroup class

A VPC security group that the cluster belongs to, if the cluster is in a VPC.

Constructors

AwsRedshiftClusterVpcSecurityGroup({String? status, String? vpcSecurityGroupId})
AwsRedshiftClusterVpcSecurityGroup.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the VPC security group.
final
vpcSecurityGroupId → String?
The identifier of the VPC security group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited