AwsS3BucketDetails class

The details of an Amazon S3 bucket.

Constructors

AwsS3BucketDetails({String? createdAt, String? ownerId, String? ownerName, AwsS3BucketServerSideEncryptionConfiguration? serverSideEncryptionConfiguration})
AwsS3BucketDetails.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
Indicates when the S3 bucket was created.
final
hashCode → int
The hash code for this object.
no setterinherited
ownerId → String?
The canonical user ID of the owner of the S3 bucket.
final
ownerName → String?
The display name of the owner of the S3 bucket.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverSideEncryptionConfiguration → AwsS3BucketServerSideEncryptionConfiguration?
The encryption rules that are applied to the S3 bucket.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited