AwsS3ObjectDetails class

Details about an Amazon S3 object.

Constructors

AwsS3ObjectDetails({String? contentType, String? eTag, String? lastModified, String? sSEKMSKeyId, String? serverSideEncryption, String? versionId})
AwsS3ObjectDetails.fromJson(Map<String, dynamic> json)
factory

Properties

contentType → String?
A standard MIME type describing the format of the object data.
final
eTag → String?
The opaque identifier assigned by a web server to a specific version of a resource found at a URL.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → String?
Indicates when the object was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverSideEncryption → String?
If the object is stored using server-side encryption, the value of the server-side encryption algorithm used when storing this object in Amazon S3.
final
sSEKMSKeyId → String?
The identifier of the AWS Key Management Service (AWS KMS) symmetric customer managed customer master key (CMK) that was used for the object.
final
versionId → String?
The version of the object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited