AwsSecretsManagerSecretDetails class

Details about an AWS Secrets Manager secret.

Constructors

AwsSecretsManagerSecretDetails({bool? deleted, String? description, String? kmsKeyId, String? name, bool? rotationEnabled, String? rotationLambdaArn, bool? rotationOccurredWithinFrequency, AwsSecretsManagerSecretRotationRules? rotationRules})
AwsSecretsManagerSecretDetails.fromJson(Map<String, dynamic> json)
factory

Properties

deleted → bool?
Whether the secret is deleted.
final
description → String?
The user-provided description of the secret.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The ARN, Key ID, or alias of the AWS KMS customer master key (CMK) used to encrypt the SecretString or SecretBinary values for versions of this secret.
final
name → String?
The name of the secret.
final
rotationEnabled → bool?
Whether rotation is enabled.
final
rotationLambdaArn → String?
The ARN of the Lambda function that rotates the secret.
final
rotationOccurredWithinFrequency → bool?
Whether the rotation occurred within the specified rotation frequency.
final
rotationRules → AwsSecretsManagerSecretRotationRules?
Defines the rotation schedule for the secret.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited