AwsSecretsManagerSecretRotationRules class

Defines the rotation schedule for the secret.

Constructors

AwsSecretsManagerSecretRotationRules({int? automaticallyAfterDays})
AwsSecretsManagerSecretRotationRules.fromJson(Map<String, dynamic> json)
factory

Properties

automaticallyAfterDays → int?
The number of days after the previous rotation to rotate the secret.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited