AwsSecurityFinding class

Provides consistent format for the contents of the Security Hub-aggregated findings. AwsSecurityFinding format enables you to share findings between AWS security services and third-party solutions, and security standards checks.

Constructors

AwsSecurityFinding({required String awsAccountId, required String createdAt, required String description, required String generatorId, required String id, required String productArn, required List<Resource> resources, required String schemaVersion, required Severity severity, required String title, required List<String> types, required String updatedAt, Compliance? compliance, int? confidence, int? criticality, String? firstObservedAt, String? lastObservedAt, List<Malware>? malware, Network? network, List<NetworkPathComponent>? networkPath, Note? note, PatchSummary? patchSummary, ProcessDetails? process, Map<String, String>? productFields, RecordState? recordState, List<RelatedFinding>? relatedFindings, Remediation? remediation, String? sourceUrl, List<ThreatIntelIndicator>? threatIntelIndicators, Map<String, String>? userDefinedFields, VerificationState? verificationState, List<Vulnerability>? vulnerabilities, Workflow? workflow, WorkflowState? workflowState})
AwsSecurityFinding.fromJson(Map<String, dynamic> json)
factory

Properties

awsAccountId → String
The AWS account ID that a finding is generated in.
final
compliance → Compliance?
This data type is exclusive to findings that are generated as the result of a check run against a specific rule in a supported security standard, such as CIS AWS Foundations. Contains security standard-related finding details.
final
confidence → int?
A finding's confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
final
createdAt → String
Indicates when the security-findings provider created the potential security issue that a finding captured.
final
criticality → int?
The level of importance assigned to the resources associated with the finding.
final
description → String
A finding's description.
final
firstObservedAt → String?
Indicates when the security-findings provider first observed the potential security issue that a finding captured.
final
generatorId → String
The identifier for the solution-specific component (a discrete unit of logic) that generated a finding. In various security-findings providers' solutions, this generator can be called a rule, a check, a detector, a plugin, etc.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The security findings provider-specific identifier for a finding.
final
lastObservedAt → String?
Indicates when the security-findings provider most recently observed the potential security issue that a finding captured.
final
malware → List<Malware>?
A list of malware related to a finding.
final
network → Network?
The details of network-related information about a finding.
final
networkPath → List<NetworkPathComponent>?
Provides information about a network path that is relevant to a finding. Each entry under NetworkPath represents a component of that path.
final
note → Note?
A user-defined note added to a finding.
final
patchSummary → PatchSummary?
Provides an overview of the patch compliance status for an instance against a selected compliance standard.
final
process → ProcessDetails?
The details of process-related information about a finding.
final
productArn → String
The ARN generated by Security Hub that uniquely identifies a product that generates findings. This can be the ARN for a third-party product that is integrated with Security Hub, or the ARN for a custom integration.
final
productFields → Map<String, String>?
A data type where security-findings providers can include additional solution-specific details that aren't part of the defined AwsSecurityFinding format.
final
recordState → RecordState?
The record state of a finding.
final
relatedFindings → List<RelatedFinding>?
A list of related findings.
final
remediation → Remediation?
A data type that describes the remediation options for a finding.
final
resources → List<Resource>
A set of resource data types that describe the resources that the finding refers to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion → String
The schema version that a finding is formatted for.
final
severity → Severity
A finding's severity.
final
sourceUrl → String?
A URL that links to a page about the current finding in the security-findings provider's solution.
final
threatIntelIndicators → List<ThreatIntelIndicator>?
Threat intelligence details related to a finding.
final
title → String
A finding's title.
final
types → List<String>
One or more finding types in the format of namespace/category/classifier that classify a finding.
final
updatedAt → String
Indicates when the security-findings provider last updated the finding record.
final
userDefinedFields → Map<String, String>?
A list of name/value string pairs associated with the finding. These are custom, user-defined fields added to a finding.
final
verificationState → VerificationState?
Indicates the veracity of a finding.
final
vulnerabilities → List<Vulnerability>?
Provides a list of vulnerabilities associated with the findings.
final
workflow → Workflow?
Provides information about the status of the investigation into a finding.
final
workflowState → WorkflowState?
The workflow state of a finding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited