AwsSnsTopicDetails class

A wrapper type for the topic's Amazon Resource Name (ARN).

Constructors

AwsSnsTopicDetails({String? kmsMasterKeyId, String? owner, List<AwsSnsTopicSubscription>? subscription, String? topicName})
AwsSnsTopicDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsMasterKeyId → String?
The ID of an AWS managed customer master key (CMK) for Amazon SNS or a custom CMK.
final
owner → String?
The subscription's owner.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → List<AwsSnsTopicSubscription>?
Subscription is an embedded property that describes the subscription endpoints of an Amazon SNS topic.
final
topicName → String?
The name of the topic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited