AwsSnsTopicSubscription class

A wrapper type for the attributes of an Amazon SNS subscription.

Constructors

AwsSnsTopicSubscription({String? endpoint, String? protocol})
AwsSnsTopicSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

endpoint → String?
The subscription's endpoint (format depends on the protocol).
final
hashCode → int
The hash code for this object.
no setterinherited
protocol → String?
The subscription's protocol.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited