AwsSqsQueueDetails class

Data about a queue.

Constructors

AwsSqsQueueDetails({String? deadLetterTargetArn, int? kmsDataKeyReusePeriodSeconds, String? kmsMasterKeyId, String? queueName})
AwsSqsQueueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

deadLetterTargetArn → String?
The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsDataKeyReusePeriodSeconds → int?
The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again.
final
kmsMasterKeyId → String?
The ID of an AWS managed customer master key (CMK) for Amazon SQS or a custom CMK.
final
queueName → String?
The name of the new queue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited