AwsWafWebAclDetails class

Details about a WAF WebACL.

Constructors

AwsWafWebAclDetails({String? defaultAction, String? name, List<AwsWafWebAclRule>? rules, String? webAclId})
AwsWafWebAclDetails.fromJson(Map<String, dynamic> json)
factory

Properties

defaultAction → String?
The action to perform if none of the rules contained in the WebACL match.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
A friendly name or description of the WebACL. You can't change the name of a WebACL after you create it.
final
rules → List<AwsWafWebAclRule>?
An array that contains the action for each rule in a WebACL, the priority of the rule, and the ID of the rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAclId → String?
A unique identifier for a WebACL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited