AwsWafWebAclRule class

Details for a rule in a WAF WebACL.

Constructors

AwsWafWebAclRule({WafAction? action, List<WafExcludedRule>? excludedRules, WafOverrideAction? overrideAction, int? priority, String? ruleId, String? type})
AwsWafWebAclRule.fromJson(Map<String, dynamic> json)
factory

Properties

action → WafAction?
Specifies the action that CloudFront or AWS WAF takes when a web request matches the conditions in the rule.
final
excludedRules → List<WafExcludedRule>?
Rules to exclude from a rule group.
final
hashCode → int
The hash code for this object.
no setterinherited
overrideAction → WafOverrideAction?
Use the OverrideAction to test your RuleGroup.
final
priority → int?
Specifies the order in which the rules in a WebACL are evaluated. Rules with a lower value for Priority are evaluated before rules with a higher value. The value must be a unique integer. If you add multiple rules to a WebACL, the values do not need to be consecutive.
final
ruleId → String?
The identifier for a rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The rule type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited