BatchUpdateFindingsUnprocessedFinding class

A finding from a BatchUpdateFindings request that Security Hub was unable to update.

Constructors

BatchUpdateFindingsUnprocessedFinding({required String errorCode, required String errorMessage, required AwsSecurityFindingIdentifier findingIdentifier})
BatchUpdateFindingsUnprocessedFinding.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String
The code associated with the error.
final
errorMessage → String
The message associated with the error.
final
findingIdentifier → AwsSecurityFindingIdentifier
The identifier of the finding that was not updated.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited