CidrBlockAssociation class

An IPv4 CIDR block association.

Constructors

CidrBlockAssociation({String? associationId, String? cidrBlock, String? cidrBlockState})
CidrBlockAssociation.fromJson(Map<String, dynamic> json)
factory

Properties

associationId → String?
The association ID for the IPv4 CIDR block.
final
cidrBlock → String?
The IPv4 CIDR block.
final
cidrBlockState → String?
Information about the state of the IPv4 CIDR block.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited