Cvss class

CVSS scores from the advisory related to the vulnerability.

Constructors

Cvss({double? baseScore, String? baseVector, String? version})
Cvss.fromJson(Map<String, dynamic> json)
factory

Properties

baseScore → double?
The base CVSS score.
final
baseVector → String?
The base scoring vector for the CVSS score.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
The version of CVSS for the CVSS score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited