DateFilter class

A date filter for querying findings.

Constructors

DateFilter({DateRange? dateRange, String? end, String? start})
DateFilter.fromJson(Map<String, dynamic> json)
factory

Properties

dateRange → DateRange?
A date range for the date filter.
final
end → String?
An end date for the date filter.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → String?
A start date for the date filter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited