DescribeActionTargetsResponse class

Constructors

DescribeActionTargetsResponse({required List<ActionTarget> actionTargets, String? nextToken})
DescribeActionTargetsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

actionTargets → List<ActionTarget>
A list of ActionTarget objects. Each object includes the ActionTargetArn, Description, and Name of a custom action target available in Security Hub.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token to use to request the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited