DescribeHubResponse class

Constructors

DescribeHubResponse({bool? autoEnableControls, String? hubArn, String? subscribedAt})
DescribeHubResponse.fromJson(Map<String, dynamic> json)
factory

Properties

autoEnableControls → bool?
Whether to automatically enable new controls when they are added to standards that are enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
hubArn → String?
The ARN of the Hub resource that was retrieved.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribedAt → String?
The date and time when Security Hub was enabled in the account.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited