DescribeOrganizationConfigurationResponse class

Constructors

DescribeOrganizationConfigurationResponse({bool? autoEnable, bool? memberAccountLimitReached})
DescribeOrganizationConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

autoEnable → bool?
Whether to automatically enable Security Hub for new accounts in the organization.
final
hashCode → int
The hash code for this object.
no setterinherited
memberAccountLimitReached → bool?
Whether the maximum number of allowed member accounts are already associated with the Security Hub administrator account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited