DescribeProductsResponse class

Constructors

DescribeProductsResponse({required List<Product> products, String? nextToken})
DescribeProductsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token to use to request the next page of results.
final
products → List<Product>
A list of products, including details for each product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited