GetEnabledStandardsResponse class

Constructors

GetEnabledStandardsResponse({String? nextToken, List<StandardsSubscription>? standardsSubscriptions})
GetEnabledStandardsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token to use to request the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardsSubscriptions → List<StandardsSubscription>?
The list of StandardsSubscriptions objects that include information about the enabled standards.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited