GetInvitationsCountResponse class

Constructors

GetInvitationsCountResponse({int? invitationsCount})
GetInvitationsCountResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
invitationsCount → int?
The number of all membership invitations sent to this Security Hub member account, not including the currently accepted invitation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited