ImportFindingsError class

The list of the findings that cannot be imported. For each finding, the list provides the error.

Constructors

ImportFindingsError({required String errorCode, required String errorMessage, required String id})
ImportFindingsError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String
The code of the error returned by the BatchImportFindings operation.
final
errorMessage → String
The message of the error returned by the BatchImportFindings operation.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The identifier of the finding that could not be updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited