InsightResultValue class

The insight result values returned by the GetInsightResults operation.

Constructors

InsightResultValue({required int count, required String groupByAttributeValue})
InsightResultValue.fromJson(Map<String, dynamic> json)
factory

Properties

count → int
The number of findings returned for each GroupByAttributeValue.
final
groupByAttributeValue → String
The value of the attribute that the findings are grouped by for the insight whose results are returned by the GetInsightResults operation.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited