InsightResults class

The insight results returned by the GetInsightResults operation.

Constructors

InsightResults({required String groupByAttribute, required String insightArn, required List<InsightResultValue> resultValues})
InsightResults.fromJson(Map<String, dynamic> json)
factory

Properties

groupByAttribute → String
The attribute that the findings are grouped by for the insight whose results are returned by the GetInsightResults operation.
final
hashCode → int
The hash code for this object.
no setterinherited
insightArn → String
The ARN of the insight whose results are returned by the GetInsightResults operation.
final
resultValues → List<InsightResultValue>
The list of insight result values returned by the GetInsightResults operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited