Invitation class

Details about an invitation.

Constructors

Invitation({String? accountId, String? invitationId, DateTime? invitedAt, String? memberStatus})
Invitation.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The account ID of the Security Hub master account that the invitation was sent from.
final
hashCode → int
The hash code for this object.
no setterinherited
invitationId → String?
The ID of the invitation sent to the member account.
final
invitedAt → DateTime?
The timestamp of when the invitation was sent.
final
memberStatus → String?
The current status of the association between the member and master accounts.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited