Ipv6CidrBlockAssociation class

An IPV6 CIDR block association.

Constructors

Ipv6CidrBlockAssociation({String? associationId, String? cidrBlockState, String? ipv6CidrBlock})
Ipv6CidrBlockAssociation.fromJson(Map<String, dynamic> json)
factory

Properties

associationId → String?
The association ID for the IPv6 CIDR block.
final
cidrBlockState → String?
Information about the state of the CIDR block.
final
hashCode → int
The hash code for this object.
no setterinherited
ipv6CidrBlock → String?
The IPv6 CIDR block.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited