ListInvitationsResponse class

Constructors

ListInvitationsResponse({List<Invitation>? invitations, String? nextToken})
ListInvitationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
invitations → List<Invitation>?
The details of the invitations returned by the operation.
final
nextToken → String?
The pagination token to use to request the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited