LoadBalancerState class

Information about the state of the load balancer.

Constructors

LoadBalancerState({String? code, String? reason})
LoadBalancerState.fromJson(Map<String, dynamic> json)
factory

Properties

code → String?
The state code. The initial state of the load balancer is provisioning.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → String?
A description of the state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited