Malware class

A list of malware related to a finding.

Constructors

Malware({required String name, String? path, MalwareState? state, MalwareType? type})
Malware.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the malware that was observed.
final
path → String?
The file system path of the malware that was observed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → MalwareState?
The state of the malware that was observed.
final
type → MalwareType?
The type of the malware that was observed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited