MapFilter class

A map filter for querying findings. Each map filter provides the field to check, the value to look for, and the comparison operator.

Constructors

MapFilter({MapFilterComparison? comparison, String? key, String? value})
MapFilter.fromJson(Map<String, dynamic> json)
factory

Properties

comparison → MapFilterComparison?
The condition to apply to the key value when querying for findings with a map filter.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
The key of the map filter. For example, for ResourceTags, Key identifies the name of the tag. For UserDefinedFields, Key is the name of the field.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
The value for the key in the map filter. Filter values are case sensitive. For example, one of the values for a tag called Department might be Security. If you provide security as the filter value, then there is no match.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited