Member class

The details about a member account.

Constructors

Member({String? accountId, String? email, DateTime? invitedAt, String? masterId, String? memberStatus, DateTime? updatedAt})
Member.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The AWS account ID of the member account.
final
email → String?
The email address of the member account.
final
hashCode → int
The hash code for this object.
no setterinherited
invitedAt → DateTime?
A timestamp for the date and time when the invitation was sent to the member account.
final
masterId → String?
The AWS account ID of the Security Hub master account associated with this member account.
final
memberStatus → String?
The status of the relationship between the member account and its master account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime?
The timestamp for the date and time when the member account was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited