Network class

The details of network-related information about a finding.

Constructors

Network({String? destinationDomain, String? destinationIpV4, String? destinationIpV6, int? destinationPort, NetworkDirection? direction, PortRange? openPortRange, String? protocol, String? sourceDomain, String? sourceIpV4, String? sourceIpV6, String? sourceMac, int? sourcePort})
Network.fromJson(Map<String, dynamic> json)
factory

Properties

destinationDomain → String?
The destination domain of network-related information about a finding.
final
destinationIpV4 → String?
The destination IPv4 address of network-related information about a finding.
final
destinationIpV6 → String?
The destination IPv6 address of network-related information about a finding.
final
destinationPort → int?
The destination port of network-related information about a finding.
final
direction → NetworkDirection?
The direction of network traffic associated with a finding.
final
hashCode → int
The hash code for this object.
no setterinherited
openPortRange → PortRange?
The range of open ports that is present on the network.
final
protocol → String?
The protocol of network-related information about a finding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDomain → String?
The source domain of network-related information about a finding.
final
sourceIpV4 → String?
The source IPv4 address of network-related information about a finding.
final
sourceIpV6 → String?
The source IPv6 address of network-related information about a finding.
final
sourceMac → String?
The source media access control (MAC) address of network-related information about a finding.
final
sourcePort → int?
The source port of network-related information about a finding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited