NetworkHeader class

Details about a network path component that occurs before or after the current component.

Constructors

NetworkHeader({NetworkPathComponentDetails? destination, String? protocol, NetworkPathComponentDetails? source})
NetworkHeader.fromJson(Map<String, dynamic> json)
factory

Properties

destination → NetworkPathComponentDetails?
Information about the destination of the component.
final
hashCode → int
The hash code for this object.
no setterinherited
protocol → String?
The protocol used for the component.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → NetworkPathComponentDetails?
Information about the origin of the component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited