NetworkPathComponent class

Information about a network path component.

Constructors

NetworkPathComponent({String? componentId, String? componentType, NetworkHeader? egress, NetworkHeader? ingress})
NetworkPathComponent.fromJson(Map<String, dynamic> json)
factory

Properties

componentId → String?
The identifier of a component in the network path.
final
componentType → String?
The type of component.
final
egress → NetworkHeader?
Information about the component that comes after the current component in the network path.
final
hashCode → int
The hash code for this object.
no setterinherited
ingress → NetworkHeader?
Information about the component that comes before the current node in the network path.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited