Note class

A user-defined note added to a finding.

Constructors

Note({required String text, required String updatedAt, required String updatedBy})
Note.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The text of a note.
final
updatedAt → String
The timestamp of when the note was updated.
final
updatedBy → String
The principal that created a note.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited