NumberFilter class

A number filter for querying findings.

Constructors

NumberFilter({double? eq, double? gte, double? lte})
NumberFilter.fromJson(Map<String, dynamic> json)
factory

Properties

eq → double?
The equal-to condition to be applied to a single field when querying for findings.
final
gte → double?
The greater-than-equal condition to be applied to a single field when querying for findings.
final
hashCode → int
The hash code for this object.
no setterinherited
lte → double?
The less-than-equal condition to be applied to a single field when querying for findings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited