PatchSummary class

Provides an overview of the patch compliance status for an instance against a selected compliance standard.

Constructors

PatchSummary({required String id, int? failedCount, int? installedCount, int? installedOtherCount, int? installedPendingReboot, int? installedRejectedCount, int? missingCount, String? operation, String? operationEndTime, String? operationStartTime, String? rebootOption})
PatchSummary.fromJson(Map<String, dynamic> json)
factory

Properties

failedCount → int?
The number of patches from the compliance standard that failed to install.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The identifier of the compliance standard that was used to determine the patch compliance status.
final
installedCount → int?
The number of patches from the compliance standard that were installed successfully.
final
installedOtherCount → int?
The number of installed patches that are not part of the compliance standard.
final
installedPendingReboot → int?
The number of patches that were applied, but that require the instance to be rebooted in order to be marked as installed.
final
installedRejectedCount → int?
The number of patches that are installed but are also on a list of patches that the customer rejected.
final
missingCount → int?
The number of patches that are part of the compliance standard but are not installed. The count includes patches that failed to install.
final
operation → String?
The type of patch operation performed. For Patch Manager, the values are SCAN and INSTALL.
final
operationEndTime → String?
Indicates when the operation completed.
final
operationStartTime → String?
Indicates when the operation started.
final
rebootOption → String?
The reboot option specified for the instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited