ProcessDetails class

The details of process-related information about a finding.

Constructors

ProcessDetails({String? launchedAt, String? name, int? parentPid, String? path, int? pid, String? terminatedAt})
ProcessDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
launchedAt → String?
Indicates when the process was launched.
final
name → String?
The name of the process.
final
parentPid → int?
The parent process ID.
final
path → String?
The path to the process executable.
final
pid → int?
The process ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminatedAt → String?
Indicates when the process was terminated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited