Product class

Contains details about a product.

Constructors

Product({required String productArn, String? activationUrl, List<String>? categories, String? companyName, String? description, List<IntegrationType>? integrationTypes, String? marketplaceUrl, String? productName, String? productSubscriptionResourcePolicy})
Product.fromJson(Map<String, dynamic> json)
factory

Properties

activationUrl → String?
The URL used to activate the product.
final
categories → List<String>?
The categories assigned to the product.
final
companyName → String?
The name of the company that provides the product.
final
description → String?
A description of the product.
final
hashCode → int
The hash code for this object.
no setterinherited
integrationTypes → List<IntegrationType>?
The types of integration that the product supports. Available values are the following.
final
marketplaceUrl → String?
The URL for the page that contains more information about the product.
final
productArn → String
The ARN assigned to the product.
final
productName → String?
The name of the product.
final
productSubscriptionResourcePolicy → String?
The resource policy associated with the product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited