RelatedFinding class

Details about a related finding.

Constructors

RelatedFinding({required String id, required String productArn})
RelatedFinding.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The product-generated identifier for a related finding.
final
productArn → String
The ARN of the product that generated a related finding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited