Remediation class

Details about the remediation steps for a finding.

Constructors

Remediation({Recommendation? recommendation})
Remediation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recommendation → Recommendation?
A recommendation on the steps to take to remediate the issue identified by a finding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited