Result class

Details about the account that was not processed.

Constructors

Result({String? accountId, String? processingResult})
Result.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
An AWS account ID of the account that was not processed.
final
hashCode → int
The hash code for this object.
no setterinherited
processingResult → String?
The reason that the account was not processed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited