SeverityUpdate class

Updates to the severity information for a finding.

Constructors

SeverityUpdate({SeverityLabel? label, int? normalized, double? product})

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → SeverityLabel?
The severity value of the finding. The allowed values are the following.
final
normalized → int?
The normalized severity for the finding. This attribute is to be deprecated in favor of Label.
final
product → double?
The native severity as defined by the AWS service or integrated partner product that generated the finding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited