SoftwarePackage class

Information about a software package.

Constructors

SoftwarePackage({String? architecture, String? epoch, String? name, String? release, String? version})
SoftwarePackage.fromJson(Map<String, dynamic> json)
factory

Properties

architecture → String?
The architecture used for the software package.
final
epoch → String?
The epoch of the software package.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the software package.
final
release → String?
The release of the software package.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
The version of the software package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited