SortCriterion class

A collection of finding attributes used to sort findings.

Constructors

SortCriterion({String? field, SortOrder? sortOrder})

Properties

field → String?
The finding attribute used to sort findings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → SortOrder?
The order used to sort findings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited