Standard class

Provides information about a specific standard.

Constructors

Standard({String? description, bool? enabledByDefault, String? name, String? standardsArn})
Standard.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A description of the standard.
final
enabledByDefault → bool?
Whether the standard is enabled by default. When Security Hub is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the standard.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardsArn → String?
The ARN of a standard.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited