StandardsControl class

Details for an individual security standard control.

Constructors

StandardsControl({String? controlId, ControlStatus? controlStatus, DateTime? controlStatusUpdatedAt, String? description, String? disabledReason, List<String>? relatedRequirements, String? remediationUrl, SeverityRating? severityRating, String? standardsControlArn, String? title})
StandardsControl.fromJson(Map<String, dynamic> json)
factory

Properties

controlId → String?
The identifier of the security standard control.
final
controlStatus → ControlStatus?
The current status of the security standard control. Indicates whether the control is enabled or disabled. Security Hub does not check against disabled controls.
final
controlStatusUpdatedAt → DateTime?
The date and time that the status of the security standard control was most recently updated.
final
description → String?
The longer description of the security standard control. Provides information about what the control is checking for.
final
disabledReason → String?
The reason provided for the most recent change in status for the control.
final
hashCode → int
The hash code for this object.
no setterinherited
relatedRequirements → List<String>?
The list of requirements that are related to this control.
final
remediationUrl → String?
A link to remediation information for the control in the Security Hub user documentation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityRating → SeverityRating?
The severity of findings generated from this security standard control.
final
standardsControlArn → String?
The ARN of the security standard control.
final
title → String?
The title of the security standard control.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited