StandardsSubscription class

A resource that represents your subscription to a supported standard.

Constructors

StandardsSubscription({required String standardsArn, required Map<String, String> standardsInput, required StandardsStatus standardsStatus, required String standardsSubscriptionArn})
StandardsSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardsArn → String
The ARN of a standard.
final
standardsInput → Map<String, String>
A key-value pair of input for the standard.
final
standardsStatus → StandardsStatus
The status of the standards subscription.
final
standardsSubscriptionArn → String
The ARN of a resource that represents your subscription to a supported standard.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited