StandardsSubscriptionRequest class

The standard that you want to enable.

Constructors

StandardsSubscriptionRequest({required String standardsArn, Map<String, String>? standardsInput})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardsArn → String
The ARN of the standard that you want to enable. To view the list of available standards and their ARNs, use the DescribeStandards operation.
final
standardsInput → Map<String, String>?
A key-value pair of input for the standard.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited