ThreatIntelIndicator class

Details about the threat intelligence related to a finding.

Constructors

ThreatIntelIndicator({ThreatIntelIndicatorCategory? category, String? lastObservedAt, String? source, String? sourceUrl, ThreatIntelIndicatorType? type, String? value})
ThreatIntelIndicator.fromJson(Map<String, dynamic> json)
factory

Properties

category → ThreatIntelIndicatorCategory?
The category of a threat intelligence indicator.
final
hashCode → int
The hash code for this object.
no setterinherited
lastObservedAt → String?
Indicates when the most recent instance of a threat intelligence indicator was observed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
The source of the threat intelligence indicator.
final
sourceUrl → String?
The URL to the page or site where you can get more information about the threat intelligence indicator.
final
type → ThreatIntelIndicatorType?
The type of threat intelligence indicator.
final
value → String?
The value of a threat intelligence indicator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited