Vulnerability class

A vulnerability associated with a finding.

Constructors

Vulnerability({required String id, List<Cvss>? cvss, List<String>? referenceUrls, List<String>? relatedVulnerabilities, VulnerabilityVendor? vendor, List<SoftwarePackage>? vulnerablePackages})
Vulnerability.fromJson(Map<String, dynamic> json)
factory

Properties

cvss → List<Cvss>?
CVSS scores from the advisory related to the vulnerability.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The identifier of the vulnerability.
final
referenceUrls → List<String>?
A list of URLs that provide additional information about the vulnerability.
final
relatedVulnerabilities → List<String>?
List of vulnerabilities that are related to this vulnerability.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendor → VulnerabilityVendor?
Information about the vendor that generates the vulnerability report.
final
vulnerablePackages → List<SoftwarePackage>?
List of software packages that have the vulnerability.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited