VulnerabilityVendor class

A vendor that generates a vulnerability report.

Constructors

VulnerabilityVendor({required String name, String? url, String? vendorCreatedAt, String? vendorSeverity, String? vendorUpdatedAt})
VulnerabilityVendor.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the vendor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
The URL of the vulnerability advisory.
final
vendorCreatedAt → String?
Indicates when the vulnerability advisory was created.
final
vendorSeverity → String?
The severity that the vendor assigned to the vulnerability.
final
vendorUpdatedAt → String?
Indicates when the vulnerability advisory was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited